@@ -54,6 +54,19 @@ GAMGI_CHEM_DS, GAMGI_CHEM_RG };
 
 enum { GAMGI_CHEM_CONTAINER = 1, GAMGI_CHEM_POLYTOPE };
 
+enum { GAMGI_CHEM_STRUCTURE_COPY = 1, GAMGI_CHEM_STRUCTURE_LINK,
+GAMGI_CHEM_STRUCTURE_NONE };
+
+enum { GAMGI_CHEM_FILTER_CLASS = 1, GAMGI_CHEM_FILTER_CHILD,
+GAMGI_CHEM_FILTER_IDENTICAL, GAMGI_CHEM_FILTER_NONE };
+
+/******************************************
+ * default policies for structure, filter *
+ ******************************************/
+
+#define GAMGI_CHEM_STRUCTURE GAMGI_CHEM_STRUCTURE_COPY
+#define GAMGI_CHEM_FILTER GAMGI_CHEM_FILTER_CLASS
+
 /*******************************************
  *         number of atomic elements       *
  *                                         *
@@ -234,16 +247,16 @@ enum { GAMGI_CHEM_CONTAINER = 1, GAMGI_CHEM_POLYTOPE };
  * coplanar: maximum range for coplanar faces  *
  ***********************************************/
 
-#define GAMGI_CHEM_POLYTOPE_TOLERANCE_WIDTH  1.0E-1
+#define GAMGI_CHEM_POLYTOPE_WIDTH  1.0E-1
 
-#define GAMGI_CHEM_POLYTOPE_TOLERANCE_LENGTH 1.0E-2
-#define GAMGI_CHEM_POLYTOPE_TOLERANCE_AREA   1.0E-2
-#define GAMGI_CHEM_POLYTOPE_TOLERANCE_VOLUME 1.0E-2
+#define GAMGI_CHEM_POLYTOPE_LENGTH 1.0E-2
+#define GAMGI_CHEM_POLYTOPE_AREA   1.0E-2
+#define GAMGI_CHEM_POLYTOPE_VOLUME 1.0E-2
 
-#define GAMGI_CHEM_POLYTOPE_TOLERANCE_VISIBLE  1.0E-10
-#define GAMGI_CHEM_POLYTOPE_TOLERANCE_COPLANAR 1.0E-02
+#define GAMGI_CHEM_POLYTOPE_VISIBLE  1.0E-10
+#define GAMGI_CHEM_POLYTOPE_COPLANAR 1.0E-02
 
-#define GAMGI_CHEM_POLYTOPE_TOLERANCE_VISIBLE_MAX  1.0E-05
-#define GAMGI_CHEM_POLYTOPE_TOLERANCE_COPLANAR_MAX 1.0E-01
+#define GAMGI_CHEM_POLYTOPE_VISIBLE_MAX  1.0E-05
+#define GAMGI_CHEM_POLYTOPE_COPLANAR_MAX 1.0E-01
 
 #endif
