@@ -113,6 +113,7 @@ char label[GAMGI_ENGINE_TOKEN];
 unsigned int number;
 int class;
 double scale;
+unsigned int task;
 struct _gamgi_object *object; 
 gamgi_dlist *dlist;
 gamgi_dlist *selection; } gamgi_object;
@@ -222,7 +223,7 @@ int node[4];
 gamgi_atom *atoms[2];
 
 gamgi_enum reference;
-gamgi_enum autonomy;
+gamgi_enum structure, filter;
 double thickness;
 
 double origin[3], center[3];
@@ -261,8 +262,7 @@ int order;
 gamgi_atom *atoms[3];
 
 gamgi_enum reference;
-gamgi_enum autonomy;
-double reciprocal;
+gamgi_enum structure, filter;
 double thickness;
 
 double origin[3], center[3];
@@ -297,8 +297,8 @@ void (*draw) (struct _gamgi_group *);
 
 gamgi_enum type;
 int atom, element, number;
-double visible, coplanar; 
-gamgi_enum autonomy;
+gamgi_enum structure, filter;
+double visible, coplanar;
 
 double origin[3], center[3];
 double quaternion[4];
@@ -361,6 +361,7 @@ struct _gamgi_molecule *next, *before; } gamgi_molecule;
 typedef struct _gamgi_cluster {
 gamgi_object object;
 
+gamgi_enum type;
 gamgi_bool faces, dots;
 
 double origin[3], center[3];
@@ -403,13 +404,13 @@ typedef struct _gamgi_cell {
 gamgi_object object;
 
 double a, b, c, ab, ac, bc;
-double v1, v2, v3, v12, v13, v23;
 double a1[3], a2[3], a3[3];
 double p1[3], p2[3], p3[3]; 
-int group;
+double v1, v2, v3, v12, v13, v23;
+double reciprocal;
 gamgi_enum lattice, type, borders;
 gamgi_bool faces, nodes;
-int n1, n2, n3; 
+int group, n1, n2, n3; 
 
 double origin[3], center[3];
 double quaternion[4];
