@@ -161,7 +161,8 @@ direction_new->node[2] = direction->node[2];
 direction_new->node[3] = direction->node[3];
 
 direction_new->reference = direction->reference;
-direction_new->autonomy = direction->autonomy;
+direction_new->structure = direction->structure;
+direction_new->filter = direction->filter;
 direction_new->thickness = direction->thickness;
 
 direction_new->atoms[0] = NULL;
@@ -235,8 +236,8 @@ plane_new->vectors = plane->vectors;
 plane_new->order = plane->order;
 
 plane_new->reference = plane->reference;
-plane_new->autonomy = plane->autonomy;
-plane_new->reciprocal = plane->reciprocal;
+plane_new->structure = plane->structure;
+plane_new->filter = plane->filter;
 plane_new->thickness = plane->thickness;
 
 plane_new->atoms[0] = NULL;
@@ -302,11 +303,11 @@ group_new->atom = group->atom;
 group_new->element = group->element;
 group_new->number = group->number;
 
+group_new->structure = group->structure;
+group_new->filter = group->filter;
 group_new->visible = group->visible;
 group_new->coplanar = group->coplanar;
 
-group_new->autonomy = group->autonomy;
-
 /**************************************
  * copy position and orientation data *
  **************************************/
@@ -384,6 +385,7 @@ void gamgi_engine_copy_out_cluster (gamgi_cluster *cluster, gamgi_cluster *clust
 int i;
 
 static_copy (GAMGI_CAST_OBJECT cluster, GAMGI_CAST_OBJECT cluster_new);
+cluster_new->type = cluster->type;
 
 /**************************************
  * copy position and orientation data *
@@ -456,6 +458,7 @@ static_copy (GAMGI_CAST_OBJECT cell, GAMGI_CAST_OBJECT cell_new);
 
 cell_new->lattice = cell->lattice;
 cell_new->group = cell->group;
+cell_new->reciprocal = cell->reciprocal;
 
 cell_new->a = cell->a;
 cell_new->b = cell->b;
