@@ -31,6 +31,7 @@ strcpy (object->name, "");
 strcpy (object->label, "");
 object->class = class;
 object->scale = GAMGI_MESA_SCALE;
+object->task = 0;
 object->selection = NULL;
 object->dlist = NULL;
 object->object = NULL;
@@ -206,7 +207,8 @@ direction->atoms[0] = NULL;
 direction->atoms[1] = NULL;
 
 direction->reference = FALSE;
-direction->autonomy = FALSE;
+direction->structure = FALSE;
+direction->filter = FALSE;
 direction->thickness = 0.0;
 
 direction->origin[0] = 0.0;
@@ -264,8 +266,8 @@ plane->atoms[1] = NULL;
 plane->atoms[2] = NULL;
 
 plane->reference = FALSE;
-plane->autonomy = FALSE;
-plane->reciprocal = 0.0;
+plane->structure = FALSE;
+plane->filter = FALSE;
 plane->thickness = 0.0;
 
 plane->origin[0] = 0.0;
@@ -316,11 +318,11 @@ group->atom = -1;
 group->element = -1;
 group->number = 0;
 
+group->structure = FALSE;
+group->filter = FALSE;
 group->visible = 0.0;
 group->coplanar = 0.0;
 
-group->autonomy = FALSE;
-
 group->origin[0] = 0.0;
 group->origin[1] = 0.0;
 group->origin[2] = 0.0;
@@ -417,6 +419,8 @@ cluster->quaternion[1] = 0.0;
 cluster->quaternion[2] = 0.0;
 cluster->quaternion[3] = 1.0;
 
+cluster->type = FALSE;
+
 cluster->points = NULL;
 cluster->loops = NULL;
 cluster->colors = NULL;
@@ -455,6 +459,7 @@ cell->object.number = gamgi_engine_number_cell_get ();
 
 cell->lattice = FALSE;
 cell->group = 0;
+cell->reciprocal = 0.0;
 
 cell->a = 0.0;
 cell->b = 0.0;
