@@ -11,6 +11,9 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_math.h"
+#include "gamgi_chem.h"
+#include "gamgi_phys.h"
 #include "gamgi_io.h"
 #include "gamgi_expat.h"
 #include "gamgi_global.h"
@@ -73,6 +76,21 @@ gamgi_io_file_fprintf (fp, string, error);
 return depth * GAMGI_EXPAT_START;
 }
 
+/***************** external function *********************
+ *                                                       *
+ *********************************************************/
+
+void gamgi_expat_export_cdata (FILE *fp,
+char *string, int depth, int *column, gamgi_bool *error)
+{
+int length = strlen (string);
+
+if (*column >= 0 && *column + length < GAMGI_EXPAT_LINE)
+  *column += length + static_middle (fp, string, error);
+else
+  *column = length + static_start (fp, string, depth, error);
+}
+
 /***************** external function *********************
  *                                                       *
  *********************************************************/
@@ -82,6 +100,11 @@ char *string, int depth, int *column, gamgi_bool *error)
 {
 int length = strlen (string);
 
+/*******************************************************************
+ * to guarantee that the element can still be closed in the same   *
+ * line, in the worst case (/>) we need to allow for 2 more spaces *
+ *******************************************************************/
+
 if (*column + length < GAMGI_EXPAT_LINE - GAMGI_EXPAT_END - 2)
   *column += length + static_middle (fp, string, error);
 else
@@ -136,6 +159,98 @@ depth_last, &output, error, element, mass, radius, red, green, blue);
 if (output == TRUE) static_end (fp, "/>", error);
 }
 
+static void static_cdata_double (int size, double *array,
+FILE *fp, int depth, gamgi_bool *error)
+{
+char string[GAMGI_ENGINE_STRING];
+int column, i;
+
+/****************
+ * double array *
+ ****************/
+
+column = -1;
+for (i = 0; i < size; i++)
+  {
+  sprintf (string, "%.*f", gamgi->gamgi->length, array[i]);
+  gamgi_expat_export_cdata (fp, string, depth, &column, error);
+  }
+}
+
+static void static_cdata_float (int size, float *array,
+FILE *fp, int depth, gamgi_bool *error)
+{
+char string[GAMGI_ENGINE_STRING];
+int column, i;
+
+/***************
+ * float array *
+ ***************/
+
+column = -1;
+for (i = 0; i < size; i++)
+  {
+  sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_COLOR, array[i]);
+  gamgi_expat_export_cdata (fp, string, depth, &column, error);
+  }
+}
+
+static void static_cdata_int (int size, int *array,
+FILE *fp, int depth, gamgi_bool *error)
+{
+char string[GAMGI_ENGINE_STRING];
+int column, i;
+
+/*************
+ * int array *
+ *************/
+
+column = -1;
+for (i = 0; i < size; i++)
+  {
+  sprintf (string, "%d", array[i]);
+  gamgi_expat_export_cdata (fp, string, depth, &column, error);
+  }
+}
+
+static void static_cdata (char *name, char *type, int size,
+void *array, gamgi_window *window, FILE *fp, int depth_parent,
+int *depth_last, gamgi_bool *error)
+{
+char string[GAMGI_ENGINE_STRING];
+int column, depth;
+
+depth = depth_parent + 1;
+if (depth > *depth_last)
+  gamgi_io_file_fprintf (fp, ">", error);
+column = strlen ("<data") + static_start (fp, "<data", depth, error);
+*depth_last = depth;
+
+sprintf (string, "name=\"%s\"", name);
+gamgi_expat_export_attribute (fp, string, depth, &column, error);
+
+sprintf (string, "type=\"%s\"", type);
+gamgi_expat_export_attribute (fp, string, depth, &column, error);
+
+sprintf (string, "size=\"%d\"", size);
+gamgi_expat_export_attribute (fp, string, depth, &column, error);
+
+gamgi_io_file_fprintf (fp, ">", error);
+
+/**************
+ * cdata here *
+ **************/
+
+if (strcmp (type, "double") == 0)
+  static_cdata_double (size, array, fp, depth, error);
+if (strcmp (type, "float") == 0)
+  static_cdata_float (size, array, fp, depth, error);
+if (strcmp (type, "int") == 0)
+  static_cdata_int (size, array, fp, depth, error);
+
+static_start (fp, "</data>", depth, error);
+}
+
 static void static_config_help (gamgi_window *window,
 FILE *fp, int depth_parent, int *depth_last, gamgi_bool *error)
 {
@@ -833,6 +948,18 @@ while (dlist != NULL)
     window, fp, depth, depth_last, id, error);
     dlist = dlist->next; }
 
+/***************************************************
+ * write cdata: each point has 3 coordinates x,y,z *
+ ***************************************************/
+
+if (plane->type == GAMGI_PHYS_POLYGON)
+  {
+  static_cdata ("points", "double", 3 * plane->n_points,
+  plane->points, window, fp, depth, depth_last, error);
+  static_cdata ("points_driver", "int", plane->n_loops,
+  plane->loops, window, fp, depth, depth_last, error);
+  }
+
 if (depth < *depth_last)
   static_start (fp, "</plane>", depth, error);
 else
@@ -931,6 +1058,18 @@ while (dlist != NULL)
     window, fp, depth, depth_last, id, error);
     dlist = dlist->next; }
 
+/***************************************************
+ * write cdata: each point has 3 coordinates x,y,z *
+ ***************************************************/
+
+if (group->type == GAMGI_CHEM_POLYTOPE)
+  {
+  static_cdata ("points", "double", 3 * group->n_points,
+  group->points, window, fp, depth, depth_last, error);
+  static_cdata ("points_driver", "int", group->n_loops,
+  group->loops, window, fp, depth, depth_last, error);
+  }
+
 if (depth < *depth_last)
   static_start (fp, "</group>", depth, error);
 else
@@ -1147,6 +1286,27 @@ while (dlist != NULL)
     window, fp, depth, depth_last, id, error);
     dlist = dlist->next; }
 
+/***********************************************
+ * write cdata: each point has 3 coordinates   *
+ * x,y,z and each color has 3 components r,g,b *
+ ***********************************************/
+
+if (cluster->type == GAMGI_CHEM_POLYTOPE)
+  {
+  if (cluster->points != NULL)
+    static_cdata ("points", "double", 3 * cluster->n_points,
+    cluster->points, window, fp, depth, depth_last, error);
+  if (cluster->loops != NULL)
+    static_cdata ("points_driver", "int", cluster->n_loops,
+    cluster->loops, window, fp, depth, depth_last, error);
+  if (cluster->colors != NULL)
+    static_cdata ("colors", "float", 3 * cluster->n_colors,
+    cluster->colors, window, fp, depth, depth_last, error);
+  if (cluster->paints != NULL)
+    static_cdata ("colors_driver", "int", cluster->n_paints,
+    cluster->paints, window, fp, depth, depth_last, error);
+  }
+
 if (depth < *depth_last)
   static_start (fp, "</cluster>", depth, error);
 else
