@@ -557,7 +557,8 @@ void gamgi_expat_export_object_direction (gamgi_direction *direction, FILE *fp,
 int depth, int *column, int *id, gamgi_bool *error)
 {
 char string[GAMGI_ENGINE_STRING];
-double origin[3], euler[3];
+double rotation[9];
+double euler[3];
 
 /*******************
  * name (optional) *
@@ -685,15 +686,31 @@ if (direction->reference == GAMGI_ENGINE_CELL)
  * Line page *
  *************/
  
-if (direction->autonomy != GAMGI_GTK_NONE)
+/**************************************************
+ * initial,final x,y,z points (required, coupled) *
+ **************************************************/
+
+if (direction->type == GAMGI_PHYS_LINE)
   {
-  if (direction->autonomy == GAMGI_GTK_PARTIAL)
-    sprintf (string, "autonomy=\"partial\"");
-  if (direction->autonomy == GAMGI_GTK_ALL)
-    sprintf (string, "autonomy=\"all\"");
+  sprintf (string, "begin_x=\"%.*f\"", gamgi->gamgi->length, direction->points[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "begin_y=\"%.*f\"", gamgi->gamgi->length, direction->points[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "begin_z=\"%.*f\"", gamgi->gamgi->length, direction->points[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "end_x=\"%.*f\"", gamgi->gamgi->length, direction->points[3]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "end_y=\"%.*f\"", gamgi->gamgi->length, direction->points[4]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "end_z=\"%.*f\"", gamgi->gamgi->length, direction->points[5]);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
+/************************
+ * thickness (required) *
+ ************************/
+
 if (direction->thickness != 0.0 &&
 direction->thickness != GAMGI_CHEM_DIRECTION_THICKNESS)
   {
@@ -709,17 +726,31 @@ direction->thickness != GAMGI_CHEM_DIRECTION_THICKNESS)
  * origin: x,y,z (optional, coupled) *
  *************************************/
 
-gamgi_math_position_direction_translation_get (direction, origin);
-
-if (fabs (origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
-|| fabs (origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
-|| fabs (origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+if (fabs (direction->origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (direction->origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (direction->origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
   {
-  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, origin[0]);
+  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, direction->origin[0]);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
-  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, origin[1]);
+  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, direction->origin[1]);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
-  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, origin[2]);
+  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, direction->origin[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/*************************************
+ * center: x,y,z (optional, coupled) *
+ *************************************/
+
+if (fabs (direction->center[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (direction->center[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (direction->center[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "center_x=\"%.*f\"", gamgi->gamgi->length, direction->center[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "center_y=\"%.*f\"", gamgi->gamgi->length, direction->center[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "center_z=\"%.*f\"", gamgi->gamgi->length, direction->center[2]);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
@@ -727,7 +758,8 @@ if (fabs (origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
  * Euler angles: e1,e2,e3 (optional, coupled) *
  **********************************************/
 
-gamgi_math_position_direction_rotation_get (direction, euler);
+gamgi_math_quaternion_to_matrix (direction->quaternion, rotation);
+gamgi_math_euler_from_matrix (rotation, euler);
 
 if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
 || fabs (euler[1] - 0.0) > GAMGI_MATH_TOLERANCE
@@ -779,7 +811,8 @@ void gamgi_expat_export_object_plane (gamgi_plane *plane, FILE *fp,
 int depth, int *column, int *id, gamgi_bool *error)
 {
 char string[GAMGI_ENGINE_STRING];
-double origin[3], euler[3];
+double rotation[9];
+double euler[3];
 
 /*******************
  * name (optional) *
@@ -880,25 +913,21 @@ if (plane->reference == GAMGI_ENGINE_CELL)
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
 
-  if (plane->type == GAMGI_PHYS_RECIPROCAL)
+  if (plane->type == GAMGI_PHYS_VECTOR)
     {
-    sprintf (string, "type=\"reciprocal\"");
+    sprintf (string, "type=\"vector\"");
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
+
   }
 
 /****************
  * Polygon page *
  ****************/
 
-if (plane->autonomy != GAMGI_GTK_NONE)
-  {
-  if (plane->autonomy == GAMGI_GTK_PARTIAL)
-    sprintf (string, "autonomy=\"partial\"");
-  if (plane->autonomy == GAMGI_GTK_ALL)
-    sprintf (string, "autonomy=\"all\"");
-  gamgi_expat_export_attribute (fp, string, depth, column, error);
-  }
+/************************
+ * thickness (optional) *
+ ************************/
 
 if (plane->thickness != 0.0 &&
 plane->thickness != GAMGI_CHEM_PLANE_THICKNESS)
@@ -915,17 +944,31 @@ plane->thickness != GAMGI_CHEM_PLANE_THICKNESS)
  * origin: x,y,z (optional, coupled) *
  *************************************/
 
-gamgi_math_position_plane_translation_get (plane, origin);
-
-if (fabs (origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
-|| fabs (origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
-|| fabs (origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+if (fabs (plane->origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (plane->origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (plane->origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
   {
-  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, origin[0]);
+  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, plane->origin[0]);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
-  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, origin[1]);
+  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, plane->origin[1]);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
-  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, origin[2]);
+  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, plane->origin[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/*************************************
+ * center: x,y,z (optional, coupled) *
+ *************************************/
+
+if (fabs (plane->center[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (plane->center[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (plane->center[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "center_x=\"%.*f\"", gamgi->gamgi->length, plane->center[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "center_y=\"%.*f\"", gamgi->gamgi->length, plane->center[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "center_z=\"%.*f\"", gamgi->gamgi->length, plane->center[2]);
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
@@ -933,7 +976,8 @@ if (fabs (origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
  * Euler angles: e1,e2,e3 (optional, coupled) *
  **********************************************/
 
-gamgi_math_position_plane_rotation_get (plane, euler);
+gamgi_math_quaternion_to_matrix (plane->quaternion, rotation);
+gamgi_math_euler_from_matrix (rotation, euler);
 
 if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
 || fabs (euler[1] - 0.0) > GAMGI_MATH_TOLERANCE
@@ -985,6 +1029,7 @@ void gamgi_expat_export_object_group (gamgi_group *group, FILE *fp,
 int depth, int *column, int *id, gamgi_bool *error)
 {
 char string[GAMGI_ENGINE_STRING];
+double rotate[9], euler[3];
 
 /*******************
  * name (optional) *
@@ -1006,6 +1051,97 @@ if (GAMGI_EXPAT_ID_GROUP == TRUE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
+/*****************
+ * Polytope page *
+ *****************/
+
+if (group->type == GAMGI_CHEM_POLYTOPE)
+  gamgi_expat_export_attribute (fp, "type=\"polytope\"", depth, column, error);
+
+/*****************
+ * Position page *
+ *****************/
+
+/*************************************
+ * origin: x,y,z (optional, coupled) *
+ *************************************/
+
+if (fabs (group->origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (group->origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (group->origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, group->origin[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, group->origin[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, group->origin[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/*************************************
+ * center: x,y,z (optional, coupled) *
+ *************************************/
+
+if (fabs (group->center[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (group->center[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (group->center[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "center_x=\"%.*f\"", gamgi->gamgi->length, group->center[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "center_y=\"%.*f\"", gamgi->gamgi->length, group->center[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "center_z=\"%.*f\"", gamgi->gamgi->length, group->center[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/**********************************************
+ * Euler angles: e1,e2,e3 (optional, coupled) *
+ **********************************************/
+
+gamgi_math_quaternion_to_matrix (group->quaternion, rotate);
+gamgi_math_euler_from_matrix (rotate, euler);
+
+if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (euler[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (euler[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "e1=\"%.*f\"", gamgi->gamgi->angle, euler[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "e2=\"%.*f\"", gamgi->gamgi->angle, euler[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "e3=\"%.*f\"", gamgi->gamgi->angle, euler[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/*************
+ * View page *
+ *************/
+
+/********************
+ * style (optional) *
+ ********************/
+
+if (group->faces == TRUE)
+  gamgi_expat_export_attribute (fp, "faces=\"yes\"", depth, column, error);
+
+/**************************************
+ * red,green,blue (optional, coupled) *
+ **************************************/
+
+if (fabs (group->red - GAMGI_MESA_GROUP_R) > GAMGI_MATH_TOLERANCE
+|| fabs (group->green - GAMGI_MESA_GROUP_G) > GAMGI_MATH_TOLERANCE
+|| fabs (group->blue - GAMGI_MESA_GROUP_B) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "red=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, group->red);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "green=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, group->green);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+
+  sprintf (string, "blue=\"%.*f\"", GAMGI_MATH_DECIMAL_COLOR, group->blue);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
 /********************
  * scale (optional) *
  ********************/
@@ -1059,6 +1195,7 @@ void gamgi_expat_export_object_cluster (gamgi_cluster *cluster, FILE *fp,
 int depth, int *column, int *id, gamgi_bool *error)
 {
 char string[GAMGI_ENGINE_STRING];
+double rotate[9], euler[3];
 
 /*******************
  * name (optional) *
@@ -1080,6 +1217,71 @@ if (GAMGI_EXPAT_ID_CLUSTER == TRUE)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
+/*****************
+ * Position data *
+ *****************/
+
+/*************************************
+ * origin: x,y,z (optional, coupled) *
+ *************************************/
+
+if (fabs (cluster->origin[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (cluster->origin[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (cluster->origin[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "x=\"%.*f\"", gamgi->gamgi->length, cluster->origin[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "y=\"%.*f\"", gamgi->gamgi->length, cluster->origin[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "z=\"%.*f\"", gamgi->gamgi->length, cluster->origin[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/*************************************
+ * center: x,y,z (optional, coupled) *
+ *************************************/
+
+if (fabs (cluster->center[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (cluster->center[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (cluster->center[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "center_x=\"%.*f\"", gamgi->gamgi->length, cluster->center[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "center_y=\"%.*f\"", gamgi->gamgi->length, cluster->center[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "center_z=\"%.*f\"", gamgi->gamgi->length, cluster->center[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/**********************************************
+ * Euler angles: e1,e2,e3 (optional, coupled) *
+ **********************************************/
+
+gamgi_math_quaternion_to_matrix (cluster->quaternion, rotate);
+gamgi_math_euler_from_matrix (rotate, euler);
+
+if (fabs (euler[0] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (euler[1] - 0.0) > GAMGI_MATH_TOLERANCE
+|| fabs (euler[2] - 0.0) > GAMGI_MATH_TOLERANCE)
+  {
+  sprintf (string, "e1=\"%.*f\"", gamgi->gamgi->angle, euler[0]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "e2=\"%.*f\"", gamgi->gamgi->angle, euler[1]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  sprintf (string, "e3=\"%.*f\"", gamgi->gamgi->angle, euler[2]);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
+/*********************************
+ * dots,faces,borders (optional) *
+ *********************************/
+
+if (cluster->dots == TRUE)
+  gamgi_expat_export_attribute (fp, "dots=\"yes\"", depth, column, error);
+
+if (cluster->faces == TRUE)
+  gamgi_expat_export_attribute (fp, "faces=\"yes\"", depth, column, error);
+
 /********************
  * scale (optional) *
  ********************/
@@ -1188,6 +1390,16 @@ if (cell->lattice == GAMGI_PHYS_TRICLINIC_P)
   gamgi_expat_export_attribute (fp, string, depth, column, error);
   }
 
+/***************************************
+ * reciprocal lattice: export constant *
+ ***************************************/
+
+if (cell->reciprocal != 0.0)
+  {
+  sprintf (string, "reciprocal=\"%.*f\"", gamgi->gamgi->length, cell->reciprocal);
+  gamgi_expat_export_attribute (fp, string, depth, column, error);
+  }
+
 /*************************************
  * origin: x,y,z (optional, coupled) *
  *************************************/
@@ -1346,9 +1558,9 @@ if (o4 == FALSE && (o1 != 0 || o2 != 0 || 03 != 0))
   if (cell->origin_vectors != GAMGI_PHYS_CELL_VECTORS_ORIGIN)
     {
     if (cell->origin_vectors == GAMGI_PHYS_CONVENTIONAL)
-      sprintf (string, "o_vectors=\"conventional\"");
+      sprintf (string, "origin_vectors=\"conventional\"");
     if (cell->origin_vectors == GAMGI_PHYS_PRIMITIVE)
-      sprintf (string, "o_vectors=\"primitive\"");
+      sprintf (string, "origin_vectors=\"primitive\"");
     gamgi_expat_export_attribute (fp, string, depth, column, error);
     }
   }
