@@ -13,14 +13,14 @@
  * external functions *
  **********************/
 
+gamgi_dlist *gamgi_global_selection_list (gamgi_enum class);
+
 void gamgi_global_selection_layer (void);
 
 void gamgi_global_selection_focus (void);
 
 void gamgi_global_selection_undo (void);
 
-void gamgi_global_selection_draw (void);
-
 void gamgi_global_selection_hide (char *name, gamgi_window *window);
 
 void gamgi_global_selection_show (char *name, gamgi_window *window);
@@ -40,8 +40,8 @@ void gamgi_global_selection_remove (gamgi_dlist **start, char *label);
 
 void gamgi_global_selection_remove_all (void);
 
-void gamgi_global_selection_clean (gamgi_dlist **start,
-gamgi_dlist *selection, char *label);
+void gamgi_global_selection_clean (gamgi_enum class,
+gamgi_dlist **start, char *label, gamgi_dlist *selection);
 
 /*************
  * Rationale *
