@@ -19,11 +19,11 @@
 
 #include "gamgi_engine_create.h"
 #include "gamgi_engine_start.h"
-#include "gamgi_engine_find.h"
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_link.h"
 #include "gamgi_engine_dlist.h"
-#include "gamgi_engine_select.h"
+#include "gamgi_engine_filter.h"
+#include "gamgi_engine_find.h"
 #include "gamgi_engine_remove.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
@@ -590,7 +590,7 @@ else
 
     if (element1 >= 0 && element2 >= 0)
       {
-      atom_list = gamgi_engine_select_atom_element (atom_list, 
+      atom_list = gamgi_engine_filter_atom_element (atom_list, 
       element1, element2);
       }
 
@@ -613,7 +613,7 @@ else
     bond_list = gamgi_chem_bond_create_voronoi (window, atom_list);
     if (min >= 0 && max >= 0)
       {
-      bond_list = gamgi_engine_select_bond_length (bond_list, 
+      bond_list = gamgi_engine_filter_bond_length (bond_list, 
       min, max);
       }
     }
@@ -626,7 +626,7 @@ else
 
   if (element1 >= 0 && element2 >= 0)
    {
-   bond_list = gamgi_engine_select_bond_element (bond_list, 
+   bond_list = gamgi_engine_filter_bond_element (bond_list, 
    element1, element2);
    }
 
