@@ -268,10 +268,10 @@ gtk_tree_model_get (model, &new, 0, &name, -1);
  * widgets can be Entry, ComboBox or Combo_Box_Entry *
  ****************************************************/
 
-if (strcmp (name, "Pick") == 0)
+if (strcmp (name, "Pick") == 0 || strcmp (name, "Region") == 0)
   {
-  gamgi_gtk_select_method_pick ("widget_min", window);
-  gamgi_gtk_select_method_pick ("widget_max", window);
+  gamgi_gtk_select_method_direct ("widget_min", window);
+  gamgi_gtk_select_method_direct ("widget_max", window);
   }
 else if (strcmp (name, "Style") == 0)
   {
@@ -896,10 +896,7 @@ else
  * to Current and the model is updated   *
  *****************************************/
 
-if (gamgi->bonds == NULL)
-  gamgi_global_selection_hide ("button_bond");
-else
-  gamgi_global_selection_show ("button_bond");
+gamgi_global_selection_update_windows (&gamgi->bonds, "button_bond");
 
 static_reset (window);
 }
