@@ -21,8 +21,9 @@
 #include "gamgi_engine_create.h"
 #include "gamgi_engine_start.h"
 #include "gamgi_engine_remove.h"
-#include "gamgi_engine_find.h"
 #include "gamgi_engine_dlist.h"
+#include "gamgi_engine_filter.h"
+#include "gamgi_engine_find.h"
 #include "gamgi_engine_link.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_object.h"
@@ -92,93 +93,47 @@ gamgi_gtk_cell_symmetry_nodes (lattice, vectors, dialog);
 static_instance (NULL, window);
 }
 
-static void static_autonomy (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-GtkWidget *button;
-GtkWidget *label;
-GtkWidget *combo;
-char token[GAMGI_ENGINE_TOKEN];
-int row;
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-/**********************************
- * enable/disable thickness entry *
- **********************************/
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_cell");
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_thickness");
-
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE || 
-row != GAMGI_GTK_NONE - 1)
-  {
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-  sprintf (token, "%.*f", gamgi->gamgi->length,
-  GAMGI_CHEM_DIRECTION_THICKNESS);
-  gtk_entry_set_text (GTK_ENTRY (entry), token);
-  }
-else
-  {
-  gtk_entry_set_text (GTK_ENTRY (entry), "");
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  }
-
-/************************
- * enable/disable scale *
- ************************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_scale");
-
-if (row == GAMGI_GTK_NONE - 1)
-  {
-  gtk_entry_set_text (GTK_ENTRY (entry), "");
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  }
-else
-  {
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-  sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
-  gtk_entry_set_text (GTK_ENTRY (entry), token);
-  }
-
-}
-
 static void static_start_scope (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
+GtkWidget *combo;
+GtkWidget *entry;
 GtkWidget *button_cell;
 GtkWidget *button_range;
 GtkWidget *button_node;
-GtkWidget *combo;
+char token[GAMGI_ENGINE_TOKEN];
+gamgi_bool active;
+
+/*****************************************
+ * structure, filter policies, thickness *
+ *****************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_STRUCTURE - 1);
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_FILTER - 1);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
+sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_DIRECTION_THICKNESS);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+/****************************************
+ * range: 1) initially the button node *
+ * is active, even if node is disabled *
+ * 2) enable, disable radio buttons    *
+ * 3) initialize node coordinates      *
+ ***************************************/
 
 button_cell = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_cell");
 button_range = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_range");
 button_node = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_node");
 
-/************************************
- * the node button should be active *
- * when node is enabled or disabled *
- ************************************/
-
 if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_node)) == FALSE)
   gtk_button_clicked (GTK_BUTTON (button_node));
 
-/*********************************
- * enable, disable radio buttons *
- *********************************/
-
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_cell)) == TRUE)
+active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_cell));
+if (active == TRUE)
   {
   gtk_widget_set_sensitive (button_range, TRUE);
   gtk_widget_set_sensitive (button_node, TRUE);
@@ -189,31 +144,23 @@ else
   gtk_widget_set_sensitive (button_node, FALSE);
   }
 
-/********************************
- * by default, autonomy is none *
- ********************************/
+gamgi_gtk_direction_create_node (active, window);
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_GTK_NONE - 1);
-static_autonomy (NULL, window);
+/****************
+ * second level *
+ ****************/
 
-/*******************
- * reset node data *
- *******************/
-
-gamgi_gtk_direction_create_node (TRUE, window);
+static_instance (NULL, window);
 }
 
 static void static_start_projection (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
-GtkWidget *entry;
-GtkWidget *label;
 
-/******************************************
- * default: Wulff net, Pole yes, Trace no *
- ******************************************/
+/*********************************
+ * Wulff net, Pole yes, Trace no *
+ *********************************/
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_wulff");
 gtk_button_clicked (GTK_BUTTON (button));
@@ -223,17 +170,6 @@ gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_trace");
 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
-
-/*****************
- * disable scale *
- *****************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-gtk_entry_set_text (GTK_ENTRY (entry), "");
-gtk_widget_set_sensitive (entry, FALSE);
-
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_scale");
-gtk_widget_set_sensitive (label, FALSE);
 }
 
 static void static_end_cell (gamgi_window *window)
@@ -290,7 +226,6 @@ else
   gtk_widget_hide (vbox_projection);
   gtk_widget_show (vbox_scope);
   static_start_scope (window);
-
   static_nodes (cell, window);
   }
 
@@ -528,24 +463,12 @@ if (*atom2 == NULL)
   return FALSE;
   }
 
-/***********************************************************
- * atoms belonging to planes and directions cannot be used *
- * to define new planes and directions, to avoid conflicts *
- ***********************************************************/
-
-if (gamgi_phys_direction_compatible (*atom1, *atom2) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid atom parents", window);
-  gamgi_engine_remove_direction (direction);
-  return FALSE;
-  }
-
 /**************************************
  * atoms must be far enough from each *
  * other to define a proper line      *
  **************************************/
 
-if (gamgi_phys_direction_line (*atom1, *atom2) == FALSE)
+if (gamgi_phys_direction_length ((*atom1)->position, (*atom2)->position) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid atom positions", window);
   gamgi_engine_remove_direction (direction);
@@ -563,13 +486,15 @@ GtkWidget *entry;
 GtkWidget *combo;
 const char *name;
 
-/*********************************
- * get type of direction link:   *
- * the default is GAMGI_GTK_NONE *
- *********************************/
+/**********************************
+ * get structure, filter policies *
+ **********************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-direction->autonomy = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
+direction->structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
+direction->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /**************************
  * get scanning thickness *
@@ -577,8 +502,7 @@ direction->autonomy = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gtk_widget_is_sensitive (entry) == TRUE &&
-gamgi_io_token_double_scan (name, &direction->thickness, 
+if (gamgi_io_token_double_scan (name, &direction->thickness, 
 GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid thickness data", window);
@@ -655,12 +579,6 @@ gamgi_bool *pole, gamgi_bool *trace, gamgi_window *window)
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
 
-/**********************************************
- * direction cannot move away from projection *
- **********************************************/
-
-direction->autonomy = GAMGI_GTK_NONE;
-
 /************************************
  * get projection: Wulff or Schmidt *
  ************************************/
@@ -740,8 +658,8 @@ if (gamgi_io_token_float_scan (name, &direction->blue, 0.0, 1.0) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (direction->autonomy != GAMGI_GTK_NONE && gamgi_io_token_double_scan (name,
-&direction->object.scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+if (gamgi_io_token_double_scan (name, &direction->object.scale,
+GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
   gamgi_engine_remove_direction (direction);
@@ -777,7 +695,6 @@ int hkl1[3], hkl2[3];
 int start1, end1;
 int start2, end2;
 gamgi_enum pole, trace;
-gamgi_bool valid;
 
 direction = gamgi_engine_create_direction ();
 gamgi_engine_start_direction (direction);
@@ -788,7 +705,7 @@ gamgi_engine_start_direction (direction);
  ***********************************/
 
 atom1 = atom2 = NULL; cell = NULL;
-pole = FALSE; trace = FALSE;
+pole = trace = FALSE;
 
 /********************************
  * get reference: cell or atoms *
@@ -801,20 +718,15 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
    * this is a crystallographic direction *
    ****************************************/
 
-  valid = static_ok_cell (direction, &cell, window);
-  if (valid == FALSE) return;
-
+  if (static_ok_cell (direction, &cell, window) == FALSE) return;
   if (cell->type == GAMGI_PHYS_PROJECTION)
     {
-    valid = static_ok_projection (direction, &pole, &trace, window);
-    if (valid == FALSE) return;
+    if (static_ok_projection (direction, &pole, &trace, window) == FALSE) return;
     }
   else
     {
-    valid = static_ok_scope (direction, cell, window);
-    if (valid == FALSE) return;
+    if (static_ok_scope (direction, cell, window) == FALSE) return;
     }
-
   }
 else
   {
@@ -822,15 +734,10 @@ else
    * this is an atomic direction *
    *******************************/
 
-  valid = static_ok_atoms (direction, &atom1, &atom2, window);
-  if (valid == FALSE) return;
-
-  valid = static_ok_scope (direction, NULL, window);
-  if (valid == FALSE) return;
+  if (static_ok_atoms (direction, &atom1, &atom2, window) == FALSE) return;
+  if (static_ok_scope (direction, NULL, window) == FALSE) return;
   }
-
-valid = static_ok_view (direction, window);
-if (valid == FALSE) return;
+if (static_ok_view (direction, window) == FALSE) return;
 
 /***************************************
  * Save current layer as undo buffer   *
@@ -866,16 +773,15 @@ if (direction->reference == GAMGI_ENGINE_ATOM)
   {
   /*************************************************************
    * this is an atomic direction: 1) get list of parent atoms  *
-   * 2) filter atoms linked to other plane or direction        *
-   * 3) reorder list so the two defining atoms come first      *
+   * 2) reorder list so the two defining atoms come first      *
    *                                                           *
    * the direction type is needed because of the rotation next *
    *************************************************************/
 
   parent = gamgi_phys_direction_parent (atom1, atom2, window);
   dlist = gamgi_engine_dlist_atom_object (parent, NULL);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
+  dlist = gamgi_engine_filter_atom (dlist, direction->filter,
+  GAMGI_ENGINE_DIRECTION, parent);
   dlist = gamgi_phys_direction_reorder (dlist, atom1, atom2);
   direction->type = GAMGI_PHYS_LINE;
 
@@ -945,6 +851,10 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, gamgi->direction->blue);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
 /******************************************
  * initialize data in second level dialog *
  ******************************************/
@@ -1003,7 +913,7 @@ else
   GAMGI_ENGINE_ATOM, FALSE, static_press);
 }
 
-void gamgi_gtk_direction_create_node (gamgi_bool state, gamgi_window *window)
+void gamgi_gtk_direction_create_node (gamgi_bool node, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *entry_o1, *entry_o2, *entry_o3;
@@ -1032,7 +942,7 @@ gtk_combo_box_set_active (GTK_COMBO_BOX (combo), FALSE);
  * enable when Cell and Node are chosen *
  ****************************************/
 
-if (state == TRUE)
+if (node == TRUE)
   {
   gtk_widget_set_sensitive (combo, TRUE);
 
@@ -1447,34 +1357,69 @@ vbox_top = gtk_vbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/********
- * Link *
- ********/
+/*************
+ * Structure *
+ *************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-table = gtk_table_new (2, 2, FALSE);
-gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
-gtk_widget_show (table);
+hbox_left = gtk_hbox_new (FALSE, 20);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Autonomy");
-gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+label = gtk_label_new ("Structure");
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
-gtk_table_attach (GTK_TABLE (table), combo, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 5);
-g_signal_connect (combo, "changed",
-G_CALLBACK (static_autonomy), window);
-g_object_set_data (G_OBJECT (dialog), "combo_autonomy", combo);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_structure", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "All", -1);
+gtk_list_store_set (store, &iter, 0, "Copy", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Partial", -1);
+gtk_list_store_set (store, &iter, 0, "Link", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "None", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+/**********
+ * Filter *
+ **********/
+
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+label = gtk_label_new ("Filter");
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_filter", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Class", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Child", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Identical", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "None", -1);
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
@@ -1488,13 +1433,16 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  * Thickness *
  *************/
 
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
 label = gtk_label_new ("Thickness");
-gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 0);
-g_object_set_data (G_OBJECT (dialog), "label_thickness", label);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_thickness", entry);
