@@ -21,9 +21,10 @@
 #include "gamgi_engine_create.h"
 #include "gamgi_engine_start.h"
 #include "gamgi_engine_remove.h"
-#include "gamgi_engine_find.h"
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_dlist.h"
+#include "gamgi_engine_filter.h"
+#include "gamgi_engine_find.h"
 #include "gamgi_engine_link.h"
 #include "gamgi_engine_unlink.h"
 #include "gamgi_engine_reparent.h"
@@ -72,14 +73,14 @@ double matrix[9], inverse[9];
 double position[3], translate[3];
 double euler[3];
 
-/*************************************************
- * get list of atoms not linked to directions or *
- * directions, including the current direction   *
- *************************************************/
+/********************************************************
+ * list only atoms directly linked to direction parent, *
+ * to avoid multiple atoms with the same coordinates    *
+ ********************************************************/
 
 dlist = gamgi_engine_dlist_atom_object (direction->object.object, NULL);
-dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
+dlist = gamgi_engine_filter_atom (dlist, direction->filter,
+GAMGI_ENGINE_DIRECTION, direction->object.object);
 
 /*****************************************************
  * get rotation and translation to transform atoms   *
@@ -795,24 +796,12 @@ if (*inside == GAMGI_GTK_PARTIAL)
   return FALSE;
   }
 
-/*************************************************************
- * atoms already belonging to planes, directions cannot be   *
- * used to define new planes, directions, to avoid conflicts *
- *************************************************************/
-
-if (*inside == GAMGI_GTK_NONE &&
-gamgi_phys_direction_compatible (*atom1, *atom2) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid atom parents", window);
-  return FALSE;
-  }
-
 /**************************************
  * atoms must be far enough from each *
  * other to define a proper line      *
  **************************************/
 
-if (gamgi_phys_direction_line (*atom1, *atom2) == FALSE)
+if (gamgi_phys_direction_length ((*atom1)->position, (*atom2)->position) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid atom parents", window);
   return FALSE;
@@ -1177,7 +1166,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   type = direction->type;
   projection = direction->projection;
-  autonomy = direction->autonomy;
   thickness = direction->thickness;
   node[0] = direction->node[0];
   node[1] = direction->node[1];
@@ -1269,7 +1257,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    ***************************************************************************/
 
   if (direction->reference == GAMGI_ENGINE_ATOM && reference == GAMGI_ENGINE_ATOM && 
-  direction->autonomy == GAMGI_GTK_ALL && autonomy != GAMGI_GTK_ALL && 
   inside == GAMGI_GTK_ALL && static_find (direction, &atom1, &atom2) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid atom parents", window);
@@ -1298,11 +1285,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
   direction->n_points = 0;
   direction->n_loops = 0;
 
-  if (direction->autonomy == GAMGI_GTK_PARTIAL ||
-  (direction->autonomy == GAMGI_GTK_NONE &&
-  direction->reference == GAMGI_ENGINE_ATOM))
-    gamgi_engine_reparent_atom (direction->atom_start, direction->object.object);
-
   parent = direction->object.object;
 
   /*****************************************************************
@@ -1311,12 +1293,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
      are maintained, copy is FALSE because the plane is maintained *
    *****************************************************************/
 
-  copy = (direction->reference != GAMGI_ENGINE_ATOM ||
-  reference != GAMGI_ENGINE_ATOM || direction->autonomy != GAMGI_GTK_ALL ||
-  autonomy != GAMGI_GTK_ALL || inside != GAMGI_GTK_ALL);
-
-  if (direction->autonomy == GAMGI_GTK_ALL && copy == TRUE)
-    {
     /************************************************
      * Before removing the direction, check if the  *
      * current object is afected. In this case, the *
@@ -1328,7 +1304,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
       gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
 
     static_remove (direction);
-    }
 
   gamgi_engine_unlink_direction (direction);
 
@@ -1345,7 +1320,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   direction->type = type;
   direction->projection = projection;
-  direction->autonomy = autonomy;
   direction->thickness = thickness;
   direction->node[0] = node[0];
   direction->node[1] = node[1];
@@ -1382,8 +1356,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   if (direction->reference == GAMGI_ENGINE_ATOM)
     {
-    if (copy == TRUE)
-      {
       /************************************************************
        * this is an atomic direction: get list of atoms in parent *
        *                                                          *
@@ -1394,17 +1366,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
       parent = gamgi_phys_direction_parent (atom1, atom2, window);
       dlist = gamgi_engine_dlist_atom_object (parent, NULL);
-      dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-      dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
-      }
-    else
-      {
-      /**********************************************
-       * get list of atoms already in the direction *
-       **********************************************/
-
-      dlist = gamgi_engine_dlist_atom_direction (direction, NULL);
-      }
+      dlist = gamgi_engine_filter_atom (dlist, direction->filter,
+      GAMGI_ENGINE_DIRECTION, parent);
 
     /**********************************************************
      * reset and build direction line AFTER linking to parent *
@@ -1417,6 +1380,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
     gamgi_math_position_direction_rotation_set (direction, zero);
     gamgi_math_position_direction_translation_set (direction, zero);
 
+    copy = TRUE;
     gamgi_phys_direction_atoms (direction, atom1, atom2, dlist, copy);
     }
 
@@ -1548,8 +1512,6 @@ if (class == GAMGI_ENGINE_DIRECTION)
        * set Direction autonomy, thickness *
        *************************************/
 
-      combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), direction->autonomy - 1);
       static_autonomy (NULL, window);
 
       entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
@@ -1611,8 +1573,6 @@ if (class == GAMGI_ENGINE_DIRECTION)
      * set Direction autonomy, thickness *
      *************************************/
 
-    combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), direction->autonomy - 1);
     static_autonomy (NULL, window);
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
@@ -1624,36 +1584,33 @@ if (class == GAMGI_ENGINE_DIRECTION)
    * set Direction orientation, position *
    ***************************************/
 
-  if (direction->autonomy != GAMGI_GTK_NONE)
-    {
-    gamgi_math_position_direction_translation_get (direction, origin);
+  gamgi_math_position_direction_translation_get (direction, origin);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[0]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+  sprintf (string, "%.*f", gamgi->gamgi->length, origin[0]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[1]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+  sprintf (string, "%.*f", gamgi->gamgi->length, origin[1]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[2]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+  sprintf (string, "%.*f", gamgi->gamgi->length, origin[2]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    gamgi_math_position_direction_rotation_get (direction, euler);
+  gamgi_math_position_direction_rotation_get (direction, euler);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[0]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
+  sprintf (string, "%.*f", gamgi->gamgi->angle, euler[0]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[1]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
+  sprintf (string, "%.*f", gamgi->gamgi->angle, euler[1]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[2]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-    }
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
+  sprintf (string, "%.*f", gamgi->gamgi->angle, euler[2]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
   /******************************
    * set Direction color, scale *
