@@ -157,42 +157,6 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
 }
 
-static void static_method_autonomy (char *label, gamgi_window *window)
-{
-GtkWidget *dialog = window->dialog0;
-GtkWidget *widget;
-GtkWidget *hbox;
-GtkWidget *combo;
-GtkListStore *store;
-GtkCellRenderer *renderer;
-GtkTreeIter iter;
-
-widget = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), label);
-hbox = gtk_widget_get_parent (widget);
-gtk_widget_destroy (widget);
-
-combo = gtk_combo_box_new ();
-gtk_box_pack_start (GTK_BOX (hbox), combo, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), label, combo);
-gtk_widget_show (combo);
-
-store = gtk_list_store_new (1, G_TYPE_STRING);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "All", -1);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Partial", -1);
-gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "None", -1);
-gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
-g_object_unref (store);
-
-renderer = gtk_cell_renderer_text_new ();
-gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
-gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
-
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
-}
-
 static void static_method_o4 (char *label, gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -314,11 +278,6 @@ else if (strcmp (name, "Reference") == 0)
   static_method_reference ("widget_min", window);
   static_method_reference ("widget_max", window);
   }
-else if (strcmp (name, "Autonomy") == 0)
-  {
-  static_method_autonomy ("widget_min", window);
-  static_method_autonomy ("widget_max", window);
-  }
 else if (strcmp (name, "O4") == 0)
   {
   static_method_o4 ("widget_min", window);
@@ -630,44 +589,6 @@ for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
 return dlist_new;
 }
 
-static gamgi_dlist *static_ok_autonomy (gamgi_dlist *dlist_old,
-gamgi_bool action, gamgi_window *window)
-{
-gamgi_direction *direction;
-gamgi_dlist *dlist, *dlist_new;
-gamgi_enum autonomy;
-gamgi_bool condition;
-int min, max;
-
-/********************
- * get range limits *
- ********************/
-
-gamgi_gtk_select_combo_int (&min, &max, window);
-
-/***********************************
- * get list of selected directions *
- ***********************************/
-
-dlist_new = NULL;
-for (dlist = dlist_old; dlist != NULL; dlist = dlist->next)
-  {
-  direction = GAMGI_CAST_DIRECTION dlist->data;
-
-  autonomy = direction->autonomy - 1;
-  if (direction->autonomy == FALSE) autonomy = GAMGI_GTK_NONE - 1;
-  condition = (autonomy >= min && autonomy <= max);
-
-  if (condition != action)
-    {
-    dlist_new = gamgi_engine_dlist_add_start (dlist_new);
-    dlist_new->data = direction;
-    }
-  }
-
-return dlist_new;
-}
-
 static gamgi_dlist *static_ok_o1 (gamgi_dlist *dlist_old,
 gamgi_bool action, gamgi_window *window)
 {
@@ -1046,8 +967,6 @@ else if (strcmp (name, "V") == 0)
 else if (strcmp (name, "W") == 0)
   dlist_new = static_ok_w (dlist_old, action, window);
 
-else if (strcmp (name, "Autonomy") == 0)
-  dlist_new = static_ok_autonomy (dlist_old, action, window);
 else if (strcmp (name, "O1") == 0)
   dlist_new = static_ok_o1 (dlist_old, action, window);
 else if (strcmp (name, "O2") == 0)
