@@ -11,10 +11,6 @@
 
 void gamgi_gtk_orbital_copy (GtkWidget *widget, void *data);
 
-void gamgi_gtk_direction_copy (GtkWidget *widget, void *data);
-
-void gamgi_gtk_plane_copy (GtkWidget *widget, void *data);
-
 void gamgi_gtk_arrow_copy (GtkWidget *widget, void *data);
 
 void gamgi_gtk_shape_copy (GtkWidget *widget, void *data);
