@@ -24,9 +24,9 @@
 #include "gamgi_engine_copy_out.h"
 #include "gamgi_engine_link.h"
 #include "gamgi_engine_unlink.h"
-#include "gamgi_engine_find.h"
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_dlist.h"
+#include "gamgi_engine_filter.h"
 #include "gamgi_engine_find.h"
 #include "gamgi_engine_number.h"
 #include "gamgi_engine_remove.h"
@@ -35,6 +35,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_gtk_group_link.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_chem_polytope.h"
 #include "gamgi_chem_atom.h"
 #include "gamgi_math_vector.h"
@@ -74,70 +75,6 @@ gamgi_enum faces;
 float red, green, blue;
 double scale; } cache;
 
-static gamgi_bool static_scan (gamgi_group *group, gamgi_dlist *start,
-double *position, gamgi_atom **central)
-{
-gamgi_atom *atom;
-gamgi_dlist *dlist;
-double x, y, z;
-
-for (dlist = start; dlist != NULL; dlist = dlist->next)
-  {
-  atom = GAMGI_CAST_ATOM dlist->data;
-  x = atom->position[0] - position[0];
-  y = atom->position[1] - position[1];
-  z = atom->position[2] - position[2];
-  if (x*x + y*y +z*z < GAMGI_MATH_TOLERANCE_LENGTH * GAMGI_MATH_TOLERANCE_LENGTH)
-    { *central = atom; return TRUE; }
-  }
-
-return FALSE;
-}
-
-static gamgi_bool static_find (gamgi_group *group, gamgi_atom **atom)
-{
-gamgi_dlist *dlist;
-double matrix[9], inverse[9];
-double position[3], translate[3];
-double euler[3];
-
-/*********************************************
- * get list of atoms not linked to planes or *
- * directions, including the current plane   *
- *********************************************/
-
-dlist = gamgi_engine_dlist_atom_object (group->object.object, NULL);
-dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_GROUP);
-dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
-
-/***************************************************
- * get rotation and translation to transform atoms *
- * back to where they would be if plane rotation   *
- * and translation were (0, 0, 0) and (0, 0, 0)    *
- ***************************************************/
-
-gamgi_math_position_group_rotation_get (group, euler);
-gamgi_math_euler_to_matrix (euler, matrix);
-gamgi_math_matrix_inverse (matrix, inverse);
-
-gamgi_math_matrix_vector (inverse, group->origin, translate);
-gamgi_math_position_translation (group->object.object, position);
-gamgi_math_vector_sub (position, translate, translate);
-
-/****************************************************************
- * try to find the original atoms of the reference atoms, where *
- * plane rotation and translation are (0, 0, 0) and (0, 0, 0)   *
- ****************************************************************/
-
-gamgi_math_matrix_vector (inverse, (*atom)->position, position);
-gamgi_math_vector_add (position, translate, position);
-
-if (static_scan (group, dlist, position, atom) == FALSE) return FALSE;
-
-return TRUE;
-}
-
 static void static_remove (gamgi_group *group)
 {
 gamgi_dlist *dlist;
@@ -657,7 +594,7 @@ if (gamgi_io_token_check (name) == TRUE)
   {
   cache.new[STATIC_VISIBLE] = TRUE;
   if (gamgi_io_token_double_scan (name, &cache.visible,
-  0.0, GAMGI_CHEM_POLYTOPE_TOLERANCE_VISIBLE_MAX) == FALSE)
+  0.0, GAMGI_CHEM_POLYTOPE_VISIBLE_MAX) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error",
     "Invalid visible face tolerance", window);
@@ -671,7 +608,7 @@ name = gtk_entry_get_text (GTK_ENTRY (entry));
 if (gamgi_io_token_check (name) == TRUE)
   {
   if (gamgi_io_token_double_scan (name, &cache.coplanar,
-  0.0, GAMGI_CHEM_POLYTOPE_TOLERANCE_COPLANAR_MAX) == FALSE)
+  0.0, GAMGI_CHEM_POLYTOPE_COPLANAR_MAX) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error",
     "Invalid coplanar face tolerance", window);
@@ -901,7 +838,6 @@ if (cache.type != STATIC_TYPE_POLYTOPE)
 
 strcpy (name, group->object.name);
 
-autonomy = group->autonomy;
 element = group->element;
 number = group->number;
 
@@ -974,19 +910,6 @@ else
     }
   }
 
-/*************************************************************************
- * polytope groups with autonomy all can be modified to autonomy partial *
- * or none, as long as the central atom in the original position can     *
- * replace that entered by the user, later removed with the group        *
- *************************************************************************/
-
-if (group->autonomy == GAMGI_GTK_ALL && autonomy != GAMGI_GTK_ALL &&
-inside == TRUE && static_find (group, &atom) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid central atom", window);
-  return FALSE;
-  }
-
 /***************************************
  * Save current layer as undo buffer   *
  * layer so it can be recovered later. *
@@ -1017,17 +940,6 @@ group->n_loops = 0;
  * prepare building conditions *
  *******************************/
 
-if (autonomy == GAMGI_GTK_NONE)
-  {
-  gamgi_math_vector_zero (origin);
-  gamgi_math_vector_zero (euler);
-  scale = 1.0;
-  }
-
-copy = (group->autonomy != GAMGI_GTK_ALL || autonomy != GAMGI_GTK_ALL || inside != TRUE);
-
-if (group->autonomy == GAMGI_GTK_ALL && copy == TRUE)
-  {
   /*************************************************
    * Before removing the group, check if the       *
    * current object is affected. In this case, the *
@@ -1039,37 +951,26 @@ if (group->autonomy == GAMGI_GTK_ALL && copy == TRUE)
     gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
 
   static_remove (group);
-  }
 
-if (copy == TRUE)
-  {
   /*****************************************
    * filter list of atoms in scope, to     *
    * avoid atoms with the same coordinates *
    *****************************************/
 
   dlist = gamgi_engine_dlist_atom_object (window->focus, NULL);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_GROUP);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
+/*
+  dlist = gamgi_engine_filter_parent_class (dlist, GAMGI_ENGINE_GROUP);
+  dlist = gamgi_engine_filter_parent_class (dlist, GAMGI_ENGINE_PLANE);
+  dlist = gamgi_engine_filter_parent_class (dlist, GAMGI_ENGINE_DIRECTION);
+*/
 
   gamgi_engine_unlink_group (group);
-  }
-else
-  {
-  /******************************************
-   * get list of atoms already in the group *
-   ******************************************/
-
-  dlist = gamgi_engine_dlist_atom_group (group, NULL);
-  }
 
 /*****************
  * save new data *
  *****************/
 
 strcpy (group->object.name, name);
-group->autonomy = autonomy;
 group->element = element;
 group->number = number;
 group->visible = visible;
@@ -1085,7 +986,11 @@ group->object.scale = scale;
  * number of independent atom positions that were found *
  ********************************************************/
 
+copy = TRUE;
+/*
 independent = gamgi_chem_polytope (dlist, group, atom, FALSE, cache.radius, copy, NULL);
+*/
+independent = 0;
 if (independent < 2)
   {
   if (group->object.object == NULL)
@@ -1168,7 +1073,7 @@ for (dlist = gamgi->cells; dlist != NULL; dlist = dlist->next)
     }
 gamgi_io_error_list (start, window);
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 
 /****************
  * reset dialog *
@@ -1324,9 +1229,6 @@ if (class == GAMGI_ENGINE_GROUP)
    * set Group autonomy, element, number, radius *
    ***********************************************/
 
-  combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-  gtk_combo_box_set_active (GTK_COMBO_BOX (combo), group->autonomy - 1);
-
   if (group->element != -1)
     {
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_element");
@@ -1342,52 +1244,49 @@ if (class == GAMGI_ENGINE_GROUP)
    * get position, orientation, scale *
    ************************************/
 
-  if (group->autonomy != GAMGI_GTK_NONE)
-    {
-    /************
-     * position *
-     ************/
+  /************
+   * position *
+   ************/
 
-    gamgi_math_position_group_translation_get (group, origin);
+  gamgi_math_position_group_translation_get (group, origin);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[0]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
+  sprintf (string, "%.*f", gamgi->gamgi->length, origin[0]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[1]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
+  sprintf (string, "%.*f", gamgi->gamgi->length, origin[1]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[2]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
+  sprintf (string, "%.*f", gamgi->gamgi->length, origin[2]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    /***************
-     * orientation *
-     ***************/
+  /***************
+   * orientation *
+   ***************/
 
-    gamgi_math_position_group_rotation_get (group, euler);
+  gamgi_math_position_group_rotation_get (group, euler);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[0]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
+  sprintf (string, "%.*f", gamgi->gamgi->angle, euler[0]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[1]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
+  sprintf (string, "%.*f", gamgi->gamgi->angle, euler[1]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[2]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
+  sprintf (string, "%.*f", gamgi->gamgi->angle, euler[2]);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
-    /*********
-     * scale *
-     *********/
+  /*********
+   * scale *
+   *********/
 
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-    sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_SCALE, group->object.scale);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-    }
+  entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+  sprintf (string, "%.*f", GAMGI_MATH_DECIMAL_SCALE, group->object.scale);
+  gtk_entry_set_text (GTK_ENTRY (entry), string);
 
   /*****************************************
    * get face tolerance: Visible, Coplanar *
