@@ -60,12 +60,12 @@ switch (window->action)
 
   case GAMGI_GTK_TEXT_COPY:
   gamgi_gtk_help_dialog_import ("Help Text Copy", 
-  "interfaces/text/copy", window, 0, n);
+  "interfaces/text/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_TEXT_SELECT:
   gamgi_gtk_help_dialog_import ("Help Text Select",  
-  "interfaces/text/select", window, 0, n);
+  "interfaces/text/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_TEXT_LINK:
@@ -126,17 +126,17 @@ switch (window->action)
 
   case GAMGI_GTK_BOND_COPY:
   gamgi_gtk_help_dialog_import ("Help Bond Copy",  
-  "interfaces/bond/copy", window, 0, n);
+  "interfaces/bond/copy", window, 1, n, "object");
   break;
 
   case GAMGI_GTK_BOND_SELECT:
   gamgi_gtk_help_dialog_import ("Help Bond Select",  
-  "interfaces/bond/select", window, 0, n);
+  "interfaces/bond/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_BOND_LINK:
   gamgi_gtk_help_dialog_import ("Help Bond Link",  
-  "interfaces/bond/link", window, 1, n, "object");
+  "interfaces/bond/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_BOND_MODIFY:
@@ -162,7 +162,7 @@ switch (window->action)
 
   case GAMGI_GTK_ATOM_COPY:
   gamgi_gtk_help_dialog_import ("Help Atom Copy",  
-  "interfaces/atom/copy", window, 2, n, "copies", "shift");
+  "interfaces/atom/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_ATOM_SELECT:
@@ -172,7 +172,7 @@ switch (window->action)
 
   case GAMGI_GTK_ATOM_LINK:
   gamgi_gtk_help_dialog_import ("Help Atom Link",  
-  "interfaces/atom/link", window, 1, n, "object");
+  "interfaces/atom/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_ATOM_MODIFY:
@@ -206,17 +206,17 @@ switch (window->action)
 
   case GAMGI_GTK_DIRECTION_COPY:
   gamgi_gtk_help_dialog_import ("Help Direction Copy",  
-  "interfaces/direction/copy", window, 0, n);
+  "interfaces/direction/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_DIRECTION_SELECT:
   gamgi_gtk_help_dialog_import ("Help Direction Select",  
-  "interfaces/direction/select", window, 0, n);
+  "interfaces/direction/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_DIRECTION_LINK:
   gamgi_gtk_help_dialog_import ("Help Direction Link",  
-  "interfaces/direction/link", window, 1, n, "object");
+  "interfaces/direction/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_DIRECTION_MODIFY:
@@ -243,17 +243,17 @@ switch (window->action)
 
   case GAMGI_GTK_PLANE_COPY:
   gamgi_gtk_help_dialog_import ("Help Plane Copy",  
-  "interfaces/plane/copy", window, 0, n);
+  "interfaces/plane/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_PLANE_SELECT:
   gamgi_gtk_help_dialog_import ("Help Plane Select",  
-  "interfaces/plane/select", window, 0, n);
+  "interfaces/plane/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_PLANE_LINK:
   gamgi_gtk_help_dialog_import ("Help Plane Link",  
-  "interfaces/plane/link", window, 1, n, "object");
+  "interfaces/plane/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_PLANE_MODIFY:
@@ -285,17 +285,17 @@ switch (window->action)
 
   case GAMGI_GTK_GROUP_COPY:
   gamgi_gtk_help_dialog_import ("Help Group Copy",  
-  "interfaces/group/copy", window, 0, n);
+  "interfaces/group/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_GROUP_SELECT:
   gamgi_gtk_help_dialog_import ("Help Group Select",  
-  "interfaces/group/select", window, 0, n);
+  "interfaces/group/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_GROUP_LINK:
   gamgi_gtk_help_dialog_import ("Help Group Link",  
-  "interfaces/group/link", window, 1, n, "object");
+  "interfaces/group/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_GROUP_MODIFY:
@@ -342,17 +342,17 @@ switch (window->action)
 
   case GAMGI_GTK_MOLECULE_COPY:
   gamgi_gtk_help_dialog_import ("Help Molecule Copy",  
-  "interfaces/molecule/copy", window, 0, n);
+  "interfaces/molecule/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_MOLECULE_SELECT:
   gamgi_gtk_help_dialog_import ("Help Molecule Select",  
-  "interfaces/molecule/select", window, 0, n);
+  "interfaces/molecule/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_MOLECULE_LINK:
   gamgi_gtk_help_dialog_import ("Help Molecule Link",  
-  "interfaces/molecule/link", window, 1, n, "object");
+  "interfaces/molecule/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_MOLECULE_MODIFY:
@@ -398,17 +398,17 @@ switch (window->action)
 
   case GAMGI_GTK_CLUSTER_COPY:
   gamgi_gtk_help_dialog_import ("Help Cluster Copy",  
-  "interfaces/cluster/copy", window, 0, n);
+  "interfaces/cluster/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_CLUSTER_SELECT:
   gamgi_gtk_help_dialog_import ("Help Cluster Select",  
-  "interfaces/cluster/select", window, 0, n);
+  "interfaces/cluster/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_CLUSTER_LINK:
   gamgi_gtk_help_dialog_import ("Help Cluster Link",  
-  "interfaces/cluster/link", window, 1, n, "object");
+  "interfaces/cluster/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_CLUSTER_MODIFY:
@@ -455,18 +455,18 @@ switch (window->action)
 
   case GAMGI_GTK_CELL_COPY:
   gamgi_gtk_help_dialog_import ("Help Cell Copy",  
-  "interfaces/cell/copy", window, 0, n);
+  "interfaces/cell/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_CELL_SELECT:
   gamgi_gtk_help_dialog_import ("Help Cell Select",  
-  "interfaces/cell/select", window, 0, n);
+  "interfaces/cell/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_CELL_LINK:
   gamgi_gtk_help_dialog_import ("Help Cell Link",  
-  "interfaces/cell/link", window, 4, n, "object", 
-  "position", "occupancy", "packing");
+  "interfaces/cell/link", window, 6, n, "object", 
+  "shift", "position", "change", "occupancy", "packing");
   break;
 
   case GAMGI_GTK_CELL_LINK_RCP:
@@ -597,17 +597,17 @@ switch (window->action)
 
   case GAMGI_GTK_ASSEMBLY_COPY:
   gamgi_gtk_help_dialog_import ("Help Assembly Copy",  
-  "interfaces/assembly/copy", window, 0, n);
+  "interfaces/assembly/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_ASSEMBLY_SELECT:
   gamgi_gtk_help_dialog_import ("Help Assembly Select",  
-  "interfaces/assembly/select", window, 0, n);
+  "interfaces/assembly/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_ASSEMBLY_LINK:
   gamgi_gtk_help_dialog_import ("Help Assembly Link",  
-  "interfaces/assembly/link", window, 1, n, "object");
+  "interfaces/assembly/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_ASSEMBLY_MODIFY:
@@ -627,17 +627,17 @@ switch (window->action)
 
   case GAMGI_GTK_LIGHT_COPY:
   gamgi_gtk_help_dialog_import ("Help Light Copy",  
-  "interfaces/light/copy", window, 0, n);
+  "interfaces/light/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_LIGHT_SELECT:
   gamgi_gtk_help_dialog_import ("Help Light Select",  
-  "interfaces/light/select", window, 0, n);
+  "interfaces/light/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_LIGHT_LINK:
   gamgi_gtk_help_dialog_import ("Help Light Link",  
-  "interfaces/light/link", window, 1, n, "object");
+  "interfaces/light/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_LIGHT_MODIFY:
@@ -663,17 +663,17 @@ switch (window->action)
 
   case GAMGI_GTK_LAYER_COPY:
   gamgi_gtk_help_dialog_import ("Help Layer Copy",  
-  "interfaces/layer/copy", window, 0, n);
+  "interfaces/layer/copy", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_LAYER_SELECT:
   gamgi_gtk_help_dialog_import ("Help Layer Select",  
-  "interfaces/layer/select", window, 0, n);
+  "interfaces/layer/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_LAYER_LINK:
   gamgi_gtk_help_dialog_import ("Help Layer Link",  
-  "interfaces/layer/link", window, 1, n, "object");
+  "interfaces/layer/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_LAYER_MODIFY:
@@ -700,17 +700,17 @@ switch (window->action)
 
   case GAMGI_GTK_WINDOW_COPY:
   gamgi_gtk_help_dialog_import ("Help Window Copy",  
-  "interfaces/window/copy", window, 0, n);
+  "interfaces/window/copy", window, 1, n, "object");
   break;
 
   case GAMGI_GTK_WINDOW_SELECT:
   gamgi_gtk_help_dialog_import ("Help Window Select",  
-  "interfaces/window/select", window, 0, n);
+  "interfaces/window/select", window, 1, n, "list");
   break;
 
   case GAMGI_GTK_WINDOW_LINK:
   gamgi_gtk_help_dialog_import ("Help Window Link",  
-  "interfaces/window/link", window, 1, n, "object");
+  "interfaces/window/link", window, 2, n, "object", "shift");
   break;
 
   case GAMGI_GTK_WINDOW_MODIFY:
