@@ -160,16 +160,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Window",
 "keywords/window", data, 0, 0);
 }
 
+static void static_interfaces_window_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Window Copy",
+"interfaces/window/copy", data, 1, 1, "object");
+}
+
 static void static_interfaces_window_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Window Select", 
-"interfaces/window/select", data, 0, 0);
+"interfaces/window/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_window_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Window Link",
-"interfaces/window/link", data, 1, 1, "object");
+"interfaces/window/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_window_remove (void *data)
@@ -197,16 +203,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Layer Create",
 "position", "visibility", "view");
 }
 
+static void static_interfaces_layer_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Layer Copy",
+"interfaces/layer/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_layer_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Layer Select", 
-"interfaces/layer/select", data, 0, 0);
+"interfaces/layer/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_layer_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Layer Link",
-"interfaces/layer/link", data, 1, 1, "object");
+"interfaces/layer/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_layer_modify (void *data)
@@ -240,16 +252,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Light Create",
 "interfaces/light/create", data, 3, 1, "geometry", "color", "attenuation");
 }
 
+static void static_interfaces_light_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Light Copy",
+"interfaces/light/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_light_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Light Select", 
-"interfaces/light/select", data, 0, 0);
+"interfaces/light/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_light_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Light Link",
-"interfaces/light/link", data, 1, 1, "object");
+"interfaces/light/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_light_modify (void *data)
@@ -282,16 +300,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Assembly Create",
 "interfaces/assembly/create", data, 0, 0);
 }
 
+static void static_interfaces_assembly_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Assembly Copy",
+"interfaces/assembly/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_assembly_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Assembly Select", 
-"interfaces/assembly/select", data, 0, 0);
+"interfaces/assembly/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_assembly_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Assembly Link",
-"interfaces/assembly/link", data, 1, 1, "object");
+"interfaces/assembly/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_assembly_remove (void *data)
@@ -349,17 +373,23 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Cell Create",
 "position", "origin", "view");
 }
 
+static void static_interfaces_cell_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Cell Copy",
+"interfaces/cell/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_cell_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Cell Select", 
-"interfaces/cell/select", data, 0, 0);
+"interfaces/cell/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_cell_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Cell Link",
-"interfaces/cell/link", data, 4, 1, "object",
-"position", "occupancy", "packing");
+"interfaces/cell/link", data, 6, 1, "object", "shift",
+"position", "change", "occupancy", "packing");
 }
 
 static void static_interfaces_cell_link_rcp (void *data)
@@ -399,16 +429,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Cluster Create",
 "interfaces/cluster/create", data, 0, 0);
 }
 
+static void static_interfaces_cluster_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Cluster Copy",
+"interfaces/cluster/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_cluster_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Cluster Select", 
-"interfaces/cluster/select", data, 0, 0);
+"interfaces/cluster/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_cluster_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Cluster Link",
-"interfaces/cluster/link", data, 1, 1, "object");
+"interfaces/cluster/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_cluster_measure (void *data)
@@ -454,16 +490,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Molecule Create",
 "interfaces/molecule/create", data, 0, 0);
 }
 
+static void static_interfaces_molecule_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Molecule Copy",
+"interfaces/molecule/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_molecule_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Molecule Select", 
-"interfaces/molecule/select", data, 0, 0);
+"interfaces/molecule/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_molecule_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Molecule Link",
-"interfaces/molecule/link", data, 1, 1, "object");
+"interfaces/molecule/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_molecule_measure (void *data)
@@ -510,6 +552,12 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Group Create",
 "tolerance", "view");
 }
 
+static void static_interfaces_group_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Group Copy",
+"interfaces/group/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_group_create_polytope (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Group Create Polytope",
@@ -519,13 +567,13 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Group Create Polytope",
 static void static_interfaces_group_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Group Select", 
-"interfaces/group/select", data, 0, 0);
+"interfaces/group/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_group_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Group Link",
-"interfaces/group/link", data, 1, 1, "object");
+"interfaces/group/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_group_modify (void *data)
@@ -586,16 +634,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Plane Create",
 "polygon", "view");
 }
 
+static void static_interfaces_plane_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Plane Copy",
+"interfaces/plane/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_plane_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Plane Select", 
-"interfaces/plane/select", data, 0, 0);
+"interfaces/plane/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_plane_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Plane Link",
-"interfaces/plane/link", data, 1, 1, "object");
+"interfaces/plane/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_plane_modify (void *data)
@@ -630,16 +684,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Direction Create",
 "line", "view");
 }
 
+static void static_interfaces_direction_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Direction Copy",
+"interfaces/direction/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_direction_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Direction Select", 
-"interfaces/direction/select", data, 0, 0);
+"interfaces/direction/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_direction_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Direction Link",
-"interfaces/direction/link", data, 1, 1, "object");
+"interfaces/direction/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_direction_modify (void *data)
@@ -677,7 +737,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Atom Create",
 static void static_interfaces_atom_copy (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Atom Copy",
-"interfaces/atom/copy", data, 2, 1, "copies", "shift");
+"interfaces/atom/copy", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_atom_select (void *data)
@@ -689,7 +749,7 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Atom Select",
 static void static_interfaces_atom_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Atom Link",
-"interfaces/atom/link", data, 1, 1, "object");
+"interfaces/atom/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_atom_modify (void *data)
@@ -734,13 +794,13 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Bond Create",
 static void static_interfaces_bond_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Bond Select", 
-"interfaces/bond/select", data, 0, 0);
+"interfaces/bond/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_bond_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Bond Link",
-"interfaces/bond/link", data, 1, 1, "object");
+"interfaces/bond/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_bond_modify (void *data)
@@ -785,16 +845,22 @@ gamgi_gtk_help_dialog_import ("Help Interfaces Text Create",
 "interfaces/text/create", data, 3, 1, "contents", "position", "view");
 }
 
+static void static_interfaces_text_copy (void *data)
+{
+gamgi_gtk_help_dialog_import ("Help Interfaces Text Copy",
+"interfaces/text/copy", data, 2, 1, "object", "shift");
+}
+
 static void static_interfaces_text_select (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Text Select", 
-"interfaces/text/select", data, 0, 0);
+"interfaces/text/select", data, 1, 1, "list");
 }
 
 static void static_interfaces_text_link (void *data)
 {
 gamgi_gtk_help_dialog_import ("Help Interfaces Text Link", 
-"interfaces/text/link", data, 1, 1, "object");
+"interfaces/text/link", data, 2, 1, "object", "shift");
 }
 
 static void static_interfaces_text_modify (void *data)
@@ -1333,6 +1399,7 @@ static_row (store, &iter2, "Import", static_interfaces_file_import);
 static_row (store, &iter2, "Export", static_interfaces_file_export);
 
 iter2 = static_row (store, &iter1, "Window", static_interfaces_window);
+static_row (store, &iter2, "Copy", static_interfaces_window_copy);
 static_row (store, &iter2, "Select", static_interfaces_window_select);
 static_row (store, &iter2, "Link", static_interfaces_window_link);
 static_row (store, &iter2, "Remove", static_interfaces_window_remove);
@@ -1340,6 +1407,7 @@ static_row (store, &iter2, "Config", static_interfaces_window_config);
 
 iter2 = static_row (store, &iter1, "Layer", static_interfaces_layer);
 static_row (store, &iter2, "Create", static_interfaces_layer_create);
+static_row (store, &iter2, "Copy", static_interfaces_layer_copy);
 static_row (store, &iter2, "Select", static_interfaces_layer_select);
 static_row (store, &iter2, "Link", static_interfaces_layer_link);
 static_row (store, &iter2, "Modify", static_interfaces_layer_modify);
@@ -1348,6 +1416,7 @@ static_row (store, &iter2, "Config", static_interfaces_layer_config);
 
 iter2 = static_row (store, &iter1, "Light", static_interfaces_light);
 static_row (store, &iter2, "Create", static_interfaces_light_create);
+static_row (store, &iter2, "Copy", static_interfaces_light_copy);
 static_row (store, &iter2, "Select", static_interfaces_light_select);
 static_row (store, &iter2, "Link", static_interfaces_light_link);
 static_row (store, &iter2, "Modify", static_interfaces_light_modify);
@@ -1356,6 +1425,7 @@ static_row (store, &iter2, "Config", static_interfaces_light_config);
 
 iter2 = static_row (store, &iter1, "Assembly", static_interfaces_assembly);
 static_row (store, &iter2, "Create", static_interfaces_assembly_create);
+static_row (store, &iter2, "Copy", static_interfaces_assembly_copy);
 static_row (store, &iter2, "Select", static_interfaces_assembly_select);
 static_row (store, &iter2, "Link", static_interfaces_assembly_link);
 static_row (store, &iter2, "Remove", static_interfaces_assembly_remove);
@@ -1371,6 +1441,7 @@ static_row (store, &iter2, "Select", static_interfaces_arrow_select);
 
 iter2 = static_row (store, &iter1, "Cell", static_interfaces_cell);
 static_row (store, &iter2, "Create", static_interfaces_cell_create);
+static_row (store, &iter2, "Copy", static_interfaces_cell_copy);
 static_row (store, &iter2, "Select", static_interfaces_cell_select);
 iter3 = static_row (store, &iter2, "Link", static_interfaces_cell_link);
 static_row (store, &iter3, "RCP", static_interfaces_cell_link_rcp);
@@ -1380,6 +1451,7 @@ static_row (store, &iter2, "Remove", static_interfaces_cell_remove);
 
 iter2 = static_row (store, &iter1, "Cluster", static_interfaces_cluster);
 static_row (store, &iter2, "Create", static_interfaces_cluster_create);
+static_row (store, &iter2, "Copy", static_interfaces_cluster_copy);
 static_row (store, &iter2, "Select", static_interfaces_cluster_select);
 static_row (store, &iter2, "Link", static_interfaces_cluster_link);
 iter3 = static_row (store, &iter2, "Measure", static_interfaces_cluster_measure);
@@ -1390,6 +1462,7 @@ static_row (store, &iter2, "Remove", static_interfaces_cluster_remove);
 
 iter2 = static_row (store, &iter1, "Molecule", static_interfaces_molecule);
 static_row (store, &iter2, "Create", static_interfaces_molecule_create);
+static_row (store, &iter2, "Copy", static_interfaces_molecule_copy);
 static_row (store, &iter2, "Select", static_interfaces_molecule_select);
 static_row (store, &iter2, "Link", static_interfaces_molecule_link);
 iter3 = static_row (store, &iter2, "Measure", static_interfaces_molecule_measure);
@@ -1400,6 +1473,7 @@ static_row (store, &iter2, "Remove", static_interfaces_molecule_remove);
 
 iter2 = static_row (store, &iter1, "Group", static_interfaces_group);
 iter3 = static_row (store, &iter2, "Create", static_interfaces_group_create);
+static_row (store, &iter2, "Copy", static_interfaces_group_copy);
 static_row (store, &iter3, "Polytope", static_interfaces_group_create_polytope);
 static_row (store, &iter2, "Select", static_interfaces_group_select);
 static_row (store, &iter2, "Link", static_interfaces_group_link);
@@ -1413,6 +1487,7 @@ static_row (store, &iter2, "Remove", static_interfaces_group_remove);
 
 iter2 = static_row (store, &iter1, "Plane", static_interfaces_plane);
 static_row (store, &iter2, "Create", static_interfaces_plane_create);
+static_row (store, &iter2, "Copy", static_interfaces_plane_copy);
 static_row (store, &iter2, "Select", static_interfaces_plane_select);
 static_row (store, &iter2, "Link", static_interfaces_plane_link);
 static_row (store, &iter2, "Modify", static_interfaces_plane_modify);
@@ -1421,6 +1496,7 @@ static_row (store, &iter2, "Remove", static_interfaces_plane_remove);
 
 iter2 = static_row (store, &iter1, "Direction", static_interfaces_direction);
 static_row (store, &iter2, "Create", static_interfaces_direction_create);
+static_row (store, &iter2, "Copy", static_interfaces_direction_copy);
 static_row (store, &iter2, "Select", static_interfaces_direction_select);
 static_row (store, &iter2, "Link", static_interfaces_direction_link);
 static_row (store, &iter2, "Modify", static_interfaces_direction_modify);
@@ -1450,6 +1526,7 @@ static_row (store, &iter2, "Select", static_interfaces_orbital_select);
 
 iter2 = static_row (store, &iter1, "Text", static_interfaces_text);
 static_row (store, &iter2, "Create", static_interfaces_text_create);
+static_row (store, &iter2, "Copy", static_interfaces_text_copy);
 static_row (store, &iter2, "Select", static_interfaces_text_select);
 static_row (store, &iter2, "Link", static_interfaces_text_link);
 static_row (store, &iter2, "Modify", static_interfaces_text_modify);
