@@ -23,6 +23,7 @@
 #include "gamgi_gtk_object.h"
 #include "gamgi_gtk_statusbar.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_math_matrix.h"
 #include "gamgi_io_token.h"
@@ -653,7 +654,7 @@ for (dlist = gamgi->layers; dlist != NULL; dlist = dlist->next)
 gamgi_io_error_list (start, window);
 
 gamgi_global_selection_focus ();
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 
 /****************
  * reset dialog *
