@@ -258,8 +258,8 @@ gtk_tree_model_get (model, &new, 0, &name, -1);
 
 if (strcmp (name, "Pick") == 0)
   {
-  gamgi_gtk_select_method_pick ("widget_min", window);
-  gamgi_gtk_select_method_pick ("widget_max", window);
+  gamgi_gtk_select_method_direct ("widget_min", window);
+  gamgi_gtk_select_method_direct ("widget_max", window);
   }
 else if (strcmp (name, "Type") == 0)
   {
@@ -1267,10 +1267,7 @@ else
  * to Current and the model is updated    *
  ******************************************/
 
-if (gamgi->layers == NULL)
-  gamgi_global_selection_hide ("button_layer");
-else
-  gamgi_global_selection_show ("button_layer");
+gamgi_global_selection_update_windows (&gamgi->layers, "button_layer");
 
 static_reset (window);
 }
