@@ -21,8 +21,9 @@
 #include "gamgi_engine_create.h"
 #include "gamgi_engine_start.h"
 #include "gamgi_engine_remove.h"
-#include "gamgi_engine_find.h"
 #include "gamgi_engine_dlist.h"
+#include "gamgi_engine_filter.h"
+#include "gamgi_engine_find.h"
 #include "gamgi_engine_link.h"
 #include "gamgi_gtk_dialog.h"
 #include "gamgi_gtk_history.h"
@@ -108,68 +109,6 @@ else
 
 }
 
-static void static_autonomy (GtkWidget *widget, void *data)
-{
-gamgi_window *window = GAMGI_CAST_WINDOW data;
-GtkWidget *dialog = window->dialog0;
-GtkWidget *entry;
-GtkWidget *button;
-GtkWidget *label;
-GtkWidget *combo;
-char token[GAMGI_ENGINE_TOKEN];
-int row;
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-row = gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
-
-/**********************************
- * enable/disable thickness entry *
- **********************************/
-
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_cell");
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_thickness");
-
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE || 
-row != GAMGI_GTK_NONE - 1)
-  {
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-  sprintf (token, "%.*f", gamgi->gamgi->length,
-  GAMGI_CHEM_PLANE_THICKNESS);
-  gtk_entry_set_text (GTK_ENTRY (entry), token);
-  }
-else
-  {
-  gtk_entry_set_text (GTK_ENTRY (entry), "");
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  }
-
-/************************
- * enable/disable scale *
- ************************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_scale");
-
-if (row == GAMGI_GTK_NONE - 1)
-  {
-  gtk_entry_set_text (GTK_ENTRY (entry), "");
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  }
-else
-  {
-  gtk_widget_set_sensitive (entry, TRUE);
-  gtk_widget_set_sensitive (label, TRUE);
-  sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
-  gtk_entry_set_text (GTK_ENTRY (entry), token);
-  }
-
-}
-
 static void static_start_scope (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
@@ -177,23 +116,38 @@ GtkWidget *button_cell;
 GtkWidget *button_node;
 GtkWidget *button_range;
 GtkWidget *combo;
+GtkWidget *entry;
+char token[GAMGI_ENGINE_TOKEN];
+gamgi_bool active;
+
+/*****************************************
+ * structure, filter policies, thickness *
+ *****************************************/
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_STRUCTURE - 1);
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
+gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_CHEM_FILTER - 1);
+
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
+sprintf (token, "%.*f", gamgi->gamgi->length, GAMGI_CHEM_PLANE_THICKNESS);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
+/****************************************
+ * range: 1) initially the button range *
+ * is active, even if range is disabled *
+ * 2) enable, disable radio buttons     *
+ * 3) initialize range limits           *
+ ****************************************/
 
 button_cell = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_cell");
 button_node = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_node");
 button_range = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_range");
 
-/*************************************
- * the button range should be active *
- * when range is enabled or disabled *
- *************************************/
-
 gtk_button_clicked (GTK_BUTTON (button_range));
-
-/*********************************
- * enable, disable radio buttons *
- *********************************/
-
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_cell)) == TRUE)
+active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_cell));
+if (active == TRUE)
   {
   gtk_widget_set_sensitive (button_range, TRUE);
   gtk_widget_set_sensitive (button_node, TRUE);
@@ -203,25 +157,11 @@ else
   gtk_widget_set_sensitive (button_range, FALSE);
   gtk_widget_set_sensitive (button_node, FALSE);
   }
+gamgi_gtk_plane_create_range (active, window);
 
-/********************************
- * by default, autonomy is none *
- ********************************/
-
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_GTK_NONE - 1);
-static_autonomy (NULL, window);
-
-/********************
- * reset range data *
- ********************/
-
-gamgi_gtk_plane_create_range (
-gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button_cell)), window);
-
-/***************************
- * reset second level data *
- ***************************/
+/************************
+ * disable second level *
+ ************************/
 
 static_instance (NULL, window);
 }
@@ -230,12 +170,10 @@ static void static_start_projection (gamgi_window *window)
 {
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
-GtkWidget *entry;
-GtkWidget *label;
 
-/******************************************
- * default: Wulff net, Pole yes, Trace no *
- ******************************************/
+/*********************************
+ * Wulff net, Pole yes, Trace no *
+ *********************************/
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_wulff");
 gtk_button_clicked (GTK_BUTTON (button));
@@ -245,17 +183,6 @@ gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 
 button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_trace");
 gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), FALSE);
-
-/*****************
- * disable scale *
- *****************/
-
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
-gtk_entry_set_text (GTK_ENTRY (entry), "");
-gtk_widget_set_sensitive (entry, FALSE);
-
-label = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "label_scale");
-gtk_widget_set_sensitive (label, FALSE);
 }
 
 static void static_end_cell (gamgi_window *window)
@@ -555,18 +482,6 @@ if (*atom3 == NULL)
   return FALSE;
   }
 
-/***********************************************************
- * atoms belonging to planes and directions cannot be used *
- * to define new planes and directions, to avoid conflicts *
- ***********************************************************/
-
-if (gamgi_phys_plane_compatible (*atom1, *atom2, *atom3) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid atom parents", window);
-  gamgi_engine_remove_plane (plane);
-  return FALSE;
-  }
-
 /**************************************
  * atoms must be far enough from each *
  * other to define a proper polygon   *
@@ -591,13 +506,15 @@ GtkWidget *combo;
 const char *name;
 int o1, o2, o3;
 
-/*******************************
- * get type of plane link: the *
- * default is GAMGI_GTK_NONE   *
- *******************************/
+/**********************************
+ * get structure, filter policies *
+ **********************************/
 
-combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-plane->autonomy = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_structure");
+plane->structure = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
+
+combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_filter");
+plane->filter = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 /**************************
  * get scanning thickness *
@@ -605,8 +522,7 @@ plane->autonomy = 1 + gtk_combo_box_get_active (GTK_COMBO_BOX (combo));
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (gtk_widget_is_sensitive (entry) == TRUE &&
-gamgi_io_token_double_scan (name, &plane->thickness, 
+if (gamgi_io_token_double_scan (name, &plane->thickness, 
 GAMGI_MATH_TOLERANCE_LENGTH, DBL_MAX) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Thickness Data", window);
@@ -674,12 +590,6 @@ gamgi_bool *trace, gamgi_window *window)
 GtkWidget *dialog = window->dialog0;
 GtkWidget *button;
 
-/**********************************************
- * direction cannot move away from projection *
- **********************************************/
-
-plane->autonomy = GAMGI_GTK_NONE;
-
 /************************************
  * get projection: Wulff or Schmidt *
  ************************************/
@@ -758,8 +668,8 @@ if (gamgi_io_token_float_scan (name, &plane->blue, 0.0, 1.0) == FALSE)
 
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
 name = gtk_entry_get_text (GTK_ENTRY (entry));
-if (plane->autonomy != GAMGI_GTK_NONE && gamgi_io_token_double_scan (name,
-&plane->object.scale, GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
+if (gamgi_io_token_double_scan (name, &plane->object.scale,
+GAMGI_MESA_SCALE_LOWER, GAMGI_MESA_SCALE_UPPER) == FALSE)
   {
   gamgi_gtk_dialog_message_create ("Error", "Invalid Scale Data", window);
   gamgi_engine_remove_plane (plane);
@@ -791,7 +701,6 @@ GtkWidget *button;
 double zero[3];
 int start, end;
 gamgi_enum pole, trace;
-gamgi_bool valid;
 
 plane = gamgi_engine_create_plane ();
 gamgi_engine_start_plane (plane);
@@ -802,7 +711,7 @@ gamgi_engine_start_plane (plane);
  ***********************************/
 
 atom1 = atom2 = atom3 = NULL; cell = NULL;
-pole = FALSE; trace = FALSE;
+pole = trace = FALSE;
 
 /********************************
  * get reference: cell or atoms *
@@ -815,20 +724,16 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE)
    * this is a crystallographic plane *
    ************************************/
 
-  valid = static_ok_cell (plane, &cell, window);
-  if (valid == FALSE) return;
+  if (static_ok_cell (plane, &cell, window) == FALSE) return;
 
   if (cell->type == GAMGI_PHYS_PROJECTION)
     {
-    valid = static_ok_projection (plane, &pole, &trace, window);
-    if (valid == FALSE) return;
+    if (static_ok_projection (plane, &pole, &trace, window) == FALSE) return;
     }
   else
     {
-    valid = static_ok_scope (plane, cell, &start, &end, window);
-    if (valid == FALSE) return;
+    if (static_ok_scope (plane, cell, &start, &end, window) == FALSE) return;
     }
-
   }
 else
   {
@@ -836,15 +741,10 @@ else
    * this is an atomic plane *
    ***************************/
 
-  valid = static_ok_atoms (plane, &atom1, &atom2, &atom3, window);
-  if (valid == FALSE) return;
-
-  valid = static_ok_scope (plane, NULL, &start, &end, window);
-  if (valid == FALSE) return;
+  if (static_ok_atoms (plane, &atom1, &atom2, &atom3, window) == FALSE) return;
+  if (static_ok_scope (plane, NULL, &start, &end, window) == FALSE) return;
   }
-
-valid = static_ok_view (plane, window);
-if (valid == FALSE) return;
+if (static_ok_view (plane, window) == FALSE) return;
 
 /***************************************
  * Save current layer as undo buffer   *
@@ -873,16 +773,15 @@ if (plane->reference == GAMGI_ENGINE_ATOM)
   {
   /**********************************************************
    * this is an atomic plane: 1) get list of parent atoms   *
-   * 2) filter atoms linked to other plane or direction     *
-   * 3) reorder list so the three defining atoms come first *
+   * 2) reorder list so the three defining atoms come first *
    *                                                        *
    * the plane type is needed because of the rotation next  *
    **********************************************************/
 
   parent = gamgi_phys_plane_parent (atom1, atom2, atom3, window);
   dlist = gamgi_engine_dlist_atom_object (parent, NULL);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
+  dlist = gamgi_engine_filter_atom (dlist, plane->filter,
+  GAMGI_ENGINE_PLANE, parent);
   dlist = gamgi_phys_plane_reorder (dlist, atom1, atom2, atom3);
   plane->type = GAMGI_PHYS_POLYGON;
 
@@ -896,7 +795,7 @@ if (plane->reference == GAMGI_ENGINE_ATOM)
   gamgi_math_position_plane_rotation_set (plane, zero);
   gamgi_math_position_plane_translation_set (plane, zero);
 
-  gamgi_phys_plane_atoms (plane, atom1, atom2, atom3, dlist, TRUE);
+  gamgi_phys_plane_atoms (plane, atom1, atom2, atom3, dlist);
   }
 
 /************************   
@@ -936,9 +835,9 @@ combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_vectors");
 gtk_combo_box_set_active (GTK_COMBO_BOX (combo), GAMGI_PHYS_CONVENTIONAL - 1);
 static_cell (NULL, window);
 
-/*****************************
- * initialize red,green,blue *
- *****************************/
+/************************************
+ * initialize red,green,blue, scale *
+ ************************************/
  
 entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_red");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, gamgi->plane->red);
@@ -952,6 +851,10 @@ entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_blue");
 sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_COLOR, gamgi->plane->blue);
 gtk_entry_set_text (GTK_ENTRY (entry), token);
 
+entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_scale");
+sprintf (token, "%.*f", GAMGI_MATH_DECIMAL_SCALE, GAMGI_MESA_SCALE);
+gtk_entry_set_text (GTK_ENTRY (entry), token);
+
 /******************************************
  * initialize data in second level dialog *
  ******************************************/
@@ -1451,34 +1354,69 @@ vbox_top = gtk_vbox_new (FALSE, 15);
 gtk_box_pack_start (GTK_BOX (vbox_center), vbox_top, FALSE, FALSE, 0);
 gtk_widget_show (vbox_top);
 
-/********
- * Link *
- ********/
+/*************
+ * Structure *
+ *************/
 
 hbox_center = gtk_hbox_new (TRUE, 0);
 gtk_box_pack_start (GTK_BOX (vbox_top), hbox_center, FALSE, FALSE, 0);
 gtk_widget_show (hbox_center);
 
-table = gtk_table_new (2, 2, FALSE);
-gtk_box_pack_start (GTK_BOX (hbox_center), table, FALSE, FALSE, 0);
-gtk_widget_show (table);
+hbox_left = gtk_hbox_new (FALSE, 20);
+gtk_box_pack_start (GTK_BOX (hbox_center), hbox_left, FALSE, FALSE, 0);
+gtk_widget_show (hbox_left);
 
-label = gtk_label_new ("Autonomy");
-gtk_table_attach (GTK_TABLE (table), label, 0, 1, 0, 1, GTK_FILL, GTK_FILL, 5, 0);
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+label = gtk_label_new ("Structure");
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 combo = gtk_combo_box_new ();
-gtk_table_attach (GTK_TABLE (table), combo, 1, 2, 0, 1, GTK_FILL, GTK_FILL, 0, 5);
-g_signal_connect (combo, "changed",
-G_CALLBACK (static_autonomy), window);
-g_object_set_data (G_OBJECT (dialog), "combo_autonomy", combo);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_structure", combo);
 gtk_widget_show (combo);
 
 store = gtk_list_store_new (1, G_TYPE_STRING);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "All", -1);
+gtk_list_store_set (store, &iter, 0, "Copy", -1);
 gtk_list_store_append (store, &iter);
-gtk_list_store_set (store, &iter, 0, "Partial", -1);
+gtk_list_store_set (store, &iter, 0, "Link", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "None", -1);
+gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
+g_object_unref (store);
+
+renderer = gtk_cell_renderer_text_new ();
+gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, FALSE);
+gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NULL);
+
+/**********
+ * Filter *
+ **********/
+
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
+label = gtk_label_new ("Filter");
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
+gtk_widget_show (label);
+
+combo = gtk_combo_box_new ();
+gtk_box_pack_start (GTK_BOX (vbox_top_top), combo, FALSE, FALSE, 0);
+g_object_set_data (G_OBJECT (dialog), "combo_filter", combo);
+gtk_widget_show (combo);
+
+store = gtk_list_store_new (1, G_TYPE_STRING);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Class", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Child", -1);
+gtk_list_store_append (store, &iter);
+gtk_list_store_set (store, &iter, 0, "Identical", -1);
 gtk_list_store_append (store, &iter);
 gtk_list_store_set (store, &iter, 0, "None", -1);
 gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
@@ -1492,13 +1430,16 @@ gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (combo), renderer, "text", 0, NU
  * Thickness *
  *************/
 
+vbox_top_top = gtk_vbox_new (FALSE, 5);
+gtk_box_pack_start (GTK_BOX (hbox_left), vbox_top_top, FALSE, FALSE, 0);
+gtk_widget_show (vbox_top_top);
+
 label = gtk_label_new ("Thickness");
-gtk_table_attach (GTK_TABLE (table), label, 0, 1, 1, 2, GTK_FILL, GTK_FILL, 5, 0);
-g_object_set_data (G_OBJECT (dialog), "label_thickness", label);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), label, FALSE, FALSE, 0);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
-gtk_table_attach (GTK_TABLE (table), entry, 1, 2, 1, 2, GTK_FILL, GTK_FILL, 0, 0);
+gtk_box_pack_start (GTK_BOX (vbox_top_top), entry, FALSE, FALSE, 0);
 gtk_entry_set_width_chars (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 gtk_entry_set_max_length (GTK_ENTRY (entry), GAMGI_GTK_CHAR_7);
 g_object_set_data (G_OBJECT (dialog), "entry_thickness", entry);
@@ -1657,7 +1598,6 @@ gtk_widget_show (hbox_left);
 
 label = gtk_label_new ("Scale");
 gtk_box_pack_start (GTK_BOX (hbox_left), label, FALSE, FALSE, 0);
-g_object_set_data (G_OBJECT (dialog), "label_scale", label);
 gtk_widget_show (label);
 
 entry = gtk_entry_new ();
