@@ -21,9 +21,10 @@
 #include "gamgi_engine_create.h"
 #include "gamgi_engine_start.h"
 #include "gamgi_engine_remove.h"
-#include "gamgi_engine_find.h"
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_dlist.h"
+#include "gamgi_engine_filter.h"
+#include "gamgi_engine_find.h"
 #include "gamgi_engine_link.h"
 #include "gamgi_engine_unlink.h"
 #include "gamgi_engine_reparent.h"
@@ -78,8 +79,10 @@ double euler[3];
  *********************************************/
 
 dlist = gamgi_engine_dlist_atom_object (plane->object.object, NULL);
-dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
+/*
+dlist = gamgi_engine_filter_parent_class (dlist, GAMGI_ENGINE_PLANE);
+dlist = gamgi_engine_filter_parent_class (dlist, GAMGI_ENGINE_DIRECTION);
+*/
 
 /***************************************************
  * get rotation and translation to transform atoms *
@@ -115,39 +118,6 @@ if (static_scan (plane, dlist, position, atom3) == FALSE) return FALSE;
 return TRUE;
 }
 
-static void static_remove (gamgi_plane *plane)
-{
-gamgi_dlist *dlist;
-
-dlist = plane->direction_start;
-while (dlist != NULL)
-  { gamgi_engine_remove_direction (GAMGI_CAST_DIRECTION dlist->data);
-    dlist = gamgi_engine_dlist_remove_start (dlist); }
-plane->direction_start = NULL;
-plane->direction_end = NULL;
-
-dlist = plane->atom_start;
-while (dlist != NULL)
-  { gamgi_engine_remove_atom (GAMGI_CAST_ATOM dlist->data);
-    dlist = gamgi_engine_dlist_remove_start (dlist); } 
-plane->atom_start = NULL;
-plane->atom_end = NULL;
-  
-dlist = plane->orbital_start;
-while (dlist != NULL)
-  { gamgi_engine_remove_orbital (GAMGI_CAST_ORBITAL dlist->data);
-    dlist = gamgi_engine_dlist_remove_start (dlist); }
-plane->orbital_start = NULL;
-plane->orbital_end = NULL;
-
-dlist = plane->text_start;
-while (dlist != NULL)
-  { gamgi_engine_remove_text (GAMGI_CAST_TEXT dlist->data);
-    dlist = gamgi_engine_dlist_remove_start (dlist); }
-plane->text_start = NULL;
-plane->text_end = NULL;
-}
-
 static GtkWidget *static_atom (GtkWidget *dialog)
 {
 GtkWidget *entry;
@@ -821,18 +791,6 @@ if (*inside == GAMGI_GTK_PARTIAL)
   return FALSE;
   }
   
-/*************************************************************
- * atoms already belonging to planes, directions cannot be   *
- * used to define new planes, directions, to avoid conflicts *
- *************************************************************/
-
-if (*inside == GAMGI_GTK_NONE && 
-gamgi_phys_plane_compatible (*atom1, *atom2, *atom3) == FALSE)
-  {
-  gamgi_gtk_dialog_message_create ("Error", "Invalid atom parents", window);
-  return FALSE;
-  }
-
 /**************************************
  * atoms must be far enough from each *
  * other to define a proper polygon   *
@@ -1273,7 +1231,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   type = plane->type;
   projection = plane->projection;
-  autonomy = plane->autonomy;
   thickness = plane->thickness;
   order = plane->order;
 
@@ -1361,7 +1318,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    ***********************************************************************/
 
   if (plane->reference == GAMGI_ENGINE_ATOM && reference == GAMGI_ENGINE_ATOM &&
-  plane->autonomy == GAMGI_GTK_ALL && autonomy != GAMGI_GTK_ALL && 
   inside == GAMGI_GTK_ALL && static_find (plane, &atom1, &atom2, &atom3) == FALSE)
     {
     gamgi_gtk_dialog_message_create ("Error", "Invalid atom parents", window);
@@ -1394,11 +1350,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    * link back plane atoms to parent *
    ***********************************/
 
-  if (plane->autonomy == GAMGI_GTK_PARTIAL ||
-  (plane->autonomy == GAMGI_GTK_NONE && 
-  plane->reference == GAMGI_ENGINE_ATOM))
-    gamgi_engine_reparent_atom (plane->atom_start, plane->object.object);
-
   parent = plane->object.object;
 
   /*****************************************************************
@@ -1408,24 +1359,8 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
    *****************************************************************/
 
   copy = (plane->reference != GAMGI_ENGINE_ATOM || 
-  reference != GAMGI_ENGINE_ATOM || plane->autonomy != GAMGI_GTK_ALL || 
   autonomy != GAMGI_GTK_ALL || inside != GAMGI_GTK_ALL);
 
-  if (plane->autonomy == GAMGI_GTK_ALL && copy == TRUE)
-    {
-    /*************************************************
-     * Before removing the plane, check if the       *
-     * current object is affected. In this case, the *
-     * current layer becomes the new current object. *
-     *************************************************/
-
-    if (gamgi_engine_find_object (window->focus,
-    GAMGI_CAST_OBJECT plane) == TRUE)
-      gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
-
-    static_remove (plane);
-    }
-
   gamgi_engine_unlink_plane (plane);
 
   /************************
@@ -1441,7 +1376,6 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
   plane->type = type;
   plane->projection = projection;
-  plane->autonomy = autonomy;
   plane->thickness = thickness;
   plane->order = order;
 
@@ -1480,8 +1414,10 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
 
       parent = gamgi_phys_plane_parent (atom1, atom2, atom3, window);
       dlist = gamgi_engine_dlist_atom_object (parent, NULL);
-      dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-      dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
+/*
+      dlist = gamgi_engine_filter_parent_class (dlist, GAMGI_ENGINE_PLANE);
+      dlist = gamgi_engine_filter_parent_class (dlist, GAMGI_ENGINE_DIRECTION);
+*/
       }
     else
       {
@@ -1503,7 +1439,7 @@ if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
     gamgi_math_position_plane_rotation_set (plane, zero);
     gamgi_math_position_plane_translation_set (plane, zero);
 
-    gamgi_phys_plane_atoms (plane, atom1, atom2, atom3, dlist, copy);
+    gamgi_phys_plane_atoms (plane, atom1, atom2, atom3, dlist);
     }
 
   gamgi_math_position_plane_rotation_set (plane, euler);
@@ -1555,7 +1491,6 @@ GtkWidget *dialog = window->dialog0;
 GtkWidget *entry;
 GtkWidget *combo;
 char string[2 * GAMGI_ENGINE_TOKEN];
-double origin[3], euler[3];
 gamgi_enum class;
 
 class = static_class (window);
@@ -1634,8 +1569,6 @@ if (class == GAMGI_ENGINE_PLANE)
        * set Plane autonomy, thickness *
        *********************************/
 
-      combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-      gtk_combo_box_set_active (GTK_COMBO_BOX (combo), plane->autonomy - 1);
       static_autonomy (NULL, window);
 
       entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
@@ -1698,7 +1631,6 @@ if (class == GAMGI_ENGINE_PLANE)
      *********************************/
 
     combo = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "combo_autonomy");
-    gtk_combo_box_set_active (GTK_COMBO_BOX (combo), plane->autonomy - 1);
     static_autonomy (NULL, window);
 
     entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_thickness");
@@ -1710,37 +1642,6 @@ if (class == GAMGI_ENGINE_PLANE)
    * set Plane orientation, position *
    ***********************************/
 
-  if (plane->autonomy != GAMGI_GTK_NONE)
-    {
-    gamgi_math_position_plane_translation_get (plane, origin);
-
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_x");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[0]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_y");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[1]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_z");
-    sprintf (string, "%.*f", gamgi->gamgi->length, origin[2]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-
-    gamgi_math_position_plane_rotation_get (plane, euler);
-
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e1");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[0]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-  
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e2");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[1]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-
-    entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_e3");
-    sprintf (string, "%.*f", gamgi->gamgi->angle, euler[2]);
-    gtk_entry_set_text (GTK_ENTRY (entry), string);
-    }
-
   /**************************
    * set Plane color, scale *
    **************************/
