@@ -22,6 +22,7 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_chem_atom.h"
 #include "gamgi_io_token.h"
 #include "gamgi_global_selection.h"
@@ -161,12 +162,10 @@ if (scope == 2)
 
   dlist = plane->atom_start;
   while (dlist != NULL)
-    { 
-    atom = GAMGI_CAST_ATOM dlist->data;
-    dlist = dlist->next;
-    gamgi_chem_atom_unlink (atom);
-    gamgi_engine_remove_atom (atom);
-    }
+    { gamgi_engine_remove_atom (GAMGI_CAST_ATOM dlist->data);
+      dlist = gamgi_engine_dlist_remove_start (dlist); }
+  plane->atom_start = NULL;
+  plane->atom_end = NULL;
 
   dlist = plane->orbital_start;
   while (dlist != NULL)
@@ -206,12 +205,10 @@ if (scope == 4)
   {
   dlist = plane->atom_start;
   while (dlist != NULL)
-    {
-    atom = GAMGI_CAST_ATOM dlist->data;
-    dlist = dlist->next;
-    gamgi_chem_atom_unlink (atom);
-    gamgi_engine_remove_atom (atom);
-    }
+    { gamgi_engine_remove_atom (GAMGI_CAST_ATOM dlist->data);
+      dlist = gamgi_engine_dlist_remove_start (dlist); }
+  plane->atom_start = NULL;
+  plane->atom_end = NULL;
   }
 
 /************************************************
@@ -311,7 +308,7 @@ if (scope < 2)
  * For all windows: redraw gl_area image *
  *****************************************/
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 }
 
 static void static_ok_local (int scope, gamgi_window *window)
