@@ -29,6 +29,7 @@
 #include "gamgi_mesa_center.h"
 #include "gamgi_mesa_rotate.h"
 #include "gamgi_mesa_translate.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_math_matrix.h"
 #include "gamgi_math_quaternion.h"
@@ -820,7 +821,7 @@ for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
     }
 gamgi_io_error_list (start, window);
 
-gamgi_global_selection_draw ();
+gamgi_mesa_draw_gamgi ();
 
 /****************
  * reset dialog *
