@@ -23,8 +23,8 @@
 #include "gamgi_gtk_history.h"
 #include "gamgi_gtk_object.h"
 #include "gamgi_gtk_window_create.h"
-#include "gamgi_mesa_translate.h"
 #include "gamgi_mesa_select.h"
+#include "gamgi_mesa_translate.h"
 #include "gamgi_math_vector.h"
 #include "gamgi_chem_bond.h"
 #include "gamgi_io_token.h"
@@ -311,28 +311,33 @@ GdkEventButton *event, int x, int y, gamgi_window *window_dialog)
 {
 GtkWidget *dialog = window_dialog->dialog0;
 GtkWidget *button;
-GtkWidget *entry;
-const char *name;
+gamgi_bool global;
+
+/************************************************************
+ * global selection can be used to select the second object *
+ * or the list of objects, not the first (main) object      *
+ ************************************************************/
+
+button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
 
 /***********************************************
  * global selection can be used only to select *
- * the second object, not the main object(s)   *
+ * the second object, not the main object      *
  ***********************************************/
 
-button = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "button_list");
-entry = (GtkWidget *) g_object_get_data (G_OBJECT (dialog), "entry_window");
-name = gtk_entry_get_text (GTK_ENTRY (entry));
-
-if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == TRUE ||
-window_dialog != window_mouse) return;
+global = TRUE;
+if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (button)) == FALSE)
+  global = FALSE;
 
 /************************************************************************
  * window_dialog is the (local) window where the dialog window was open *
  * window_mouse is the (global) window where the user presses the mouse *
  ************************************************************************/
 
+if (global == FALSE && window_dialog != window_mouse) return;
+
 gamgi_mesa_select_object (window_mouse, x, y, 
-GAMGI_ENGINE_WINDOW, TRUE, static_press);
+GAMGI_ENGINE_WINDOW, global, static_press);
 }
 
 /*************** external function *************
