@@ -200,24 +200,16 @@ if (event->type == GDK_BUTTON_PRESS)
     {
     class = GAMGI_POINTER_TO_INT (g_object_get_data (G_OBJECT (menu), "select"));
 
-    if ((class != GAMGI_ENGINE_GAMGI && class != GAMGI_ENGINE_WINDOW &&
-    class != GAMGI_ENGINE_LAYER) || window->class != class)
-      window->class = class;
-    else
-      {
-      window->class = FALSE;
+    if (class == GAMGI_ENGINE_GAMGI && window->class != FALSE)
+      gamgi_gtk_object_focus_global (window);
+    else if (class == GAMGI_ENGINE_WINDOW && window->class == class)
+      gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window, window);
+    else if (class == GAMGI_ENGINE_LAYER && window->class == class)
+      gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
+    else { window->class = class; return TRUE; }
 
-      if (class == GAMGI_ENGINE_GAMGI)
-        gamgi_gtk_object_focus_global ();
-
-      if (class == GAMGI_ENGINE_WINDOW)
-        gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window, window);
-
-      if (class == GAMGI_ENGINE_LAYER)
-        gamgi_gtk_object_focus_local (GAMGI_CAST_OBJECT window->layer, window);
-
-      gamgi_gtk_dialog_beep ();
-      }
+    window->class = FALSE;
+    gamgi_gtk_dialog_beep ();
     }
   return TRUE;
   }
@@ -1257,8 +1249,6 @@ gtk_statusbar_set_has_resize_grip  (GTK_STATUSBAR (window->statusbar_layer), FAL
 gtk_widget_show (window->statusbar_layer);
 
 window->statusbar_time = gtk_statusbar_new ();
-gtk_misc_set_alignment (GTK_MISC (GTK_STATUSBAR
-(window->statusbar_time)->label), 0.5, 0.5);
 gtk_widget_set_size_request (window->statusbar_time, 80, -1);
 gtk_box_pack_start (GTK_BOX (hbox), window->statusbar_time, FALSE, FALSE, 0);
 window->context_time = gtk_statusbar_get_context_id (GTK_STATUSBAR
