@@ -288,7 +288,7 @@ glPushMatrix ();
 
 glColor3f (direction->red, direction->green, direction->blue);
 
-if (direction->autonomy != GAMGI_GTK_NONE)
+if (direction->type == GAMGI_PHYS_LINE)
   {
   glTranslatef (direction->center[0], direction->center[1], direction->center[2]);
   glScalef (direction->object.scale, direction->object.scale, direction->object.scale);
@@ -311,15 +311,13 @@ if (direction->type == GAMGI_PHYS_LINE)
 
 else if (direction->type == GAMGI_PHYS_POLE)
   {
-  glPointSize (4.0);
   gamgi_mesa_render_points_chess (direction->loops[0],
-  direction->points, GAMGI_MESA_PLANE_WIDTH);
-  glPointSize (1.0);
+  direction->points, GAMGI_MESA_POLE_WIDTH * direction->object.scale);
   }
 
 else if (direction->type == GAMGI_PHYS_TRACE)
   {
-  glLineWidth (1.0);
+  glLineWidth (GAMGI_MESA_TRACE_WIDTH * direction->object.scale);
   gamgi_mesa_render_line_strip (direction->loops[0], direction->points);
   glLineWidth (1.0);
   }
@@ -351,12 +349,13 @@ void gamgi_mesa_draw_plane (gamgi_plane *plane)
 {
 gamgi_dlist *dlist;
 double rotate[16];
+float background[4];
 
 glPushMatrix ();
 
 glColor3f (plane->red, plane->green, plane->blue);
 
-if (plane->autonomy != GAMGI_GTK_NONE)
+if (plane->type == GAMGI_PHYS_POLYGON)
   {
   glTranslatef (plane->center[0], plane->center[1], plane->center[2]);
   glScalef (plane->object.scale, plane->object.scale, plane->object.scale);
@@ -365,7 +364,12 @@ if (plane->autonomy != GAMGI_GTK_NONE)
 
 glPushMatrix ();
 
-if (plane->reciprocal == 0.0)
+if (plane->type == GAMGI_PHYS_VECTOR)
+  {
+  gamgi_mesa_render_points_cross (plane->loops[0],
+  plane->origin, GAMGI_MESA_POLE_WIDTH * plane->object.scale);
+  }
+else
   {
   glTranslatef (plane->origin[0], plane->origin[1], plane->origin[2]);
 
@@ -377,35 +381,31 @@ if (plane->reciprocal == 0.0)
     glLightModeli (GL_LIGHT_MODEL_TWO_SIDE, GL_TRUE);
     glDisable(GL_CULL_FACE);
     glEnable (GL_POLYGON_OFFSET_FILL);
-    glPolygonOffset (2, 2);
-
+    glPolygonOffset (1, 1);
     gamgi_mesa_render_polygons (plane->loops, plane->points);
-
     glDisable (GL_POLYGON_OFFSET_FILL);
     glEnable(GL_CULL_FACE);
     glLightModeli (GL_LIGHT_MODEL_TWO_SIDE, GL_FALSE);
+
+    glGetFloatv (GL_COLOR_CLEAR_VALUE, background);
+    glColor3fv (background);
+    glLineWidth (2.0);
+    gamgi_mesa_render_loops (plane->loops, plane->points);
+    glLineWidth (1.0);
     }
 
   else if (plane->type == GAMGI_PHYS_POLE)
     {
-    glPointSize (4.0);
     gamgi_mesa_render_points_cross (plane->loops[0], 
-    plane->points, GAMGI_MESA_PLANE_WIDTH);
-    glPointSize (1.0);
+    plane->points, GAMGI_MESA_POLE_WIDTH * plane->object.scale);
     }
 
   else if (plane->type == GAMGI_PHYS_TRACE)
     {
-    glLineWidth (1.0);
+    glLineWidth (GAMGI_MESA_TRACE_WIDTH * plane->object.scale);
     gamgi_mesa_render_line_strip (plane->loops[0], plane->points);
     glLineWidth (1.0);
     }
-
-  }
-else
-  {
-  gamgi_mesa_render_points_cross (plane->loops[0],
-  plane->origin, GAMGI_MESA_PLANE_WIDTH);
   }
 
 glPopMatrix ();
@@ -760,7 +760,7 @@ glPointSize (GAMGI_MESA_CELL_POINT);
 if (cell->faces == TRUE)
   {
   glEnable (GL_POLYGON_OFFSET_FILL);
-  glPolygonOffset (1, 1);
+  glPolygonOffset (2, 2);
 
   glPolygonMode (GL_FRONT, GL_FILL);
   glDisable(GL_CULL_FACE);
@@ -1322,15 +1322,13 @@ gamgi_mesa_select_draw (window);
 
 void gamgi_mesa_draw_gamgi (void) 
 {
-gamgi_window *window = gamgi->window_start;
+gamgi_window *window;
 
 /********************
  * draw all windows *
  ********************/
 
-while (window != NULL)
-  {
+for (window = gamgi->window_start; window != NULL; window = window->next)
   gtk_widget_queue_draw (window->area);
-  window = window->next;
-  }
+
 }
