@@ -11,11 +11,54 @@
 
 #include "gamgi_engine.h"
 #include "gamgi_gtk.h"
+#include "gamgi_phys.h"
 #include "gamgi_global.h"
 
+#include "gamgi_engine_find.h"
 #include "gamgi_mesa_translate_out.h"
+#include "gamgi_mesa_draw.h"
 #include "gamgi_math_vector.h"
 
+static void static_translate (gamgi_layer *layer, double *shift, double *translate)
+{
+double *referential;
+double x[3], y[3], z[3];
+
+referential = layer->referential;
+gamgi_math_vector_absolute (x, referential[0], referential[3], referential[6]);
+gamgi_math_vector_absolute (y, referential[1], referential[4], referential[7]);
+gamgi_math_vector_absolute (z, referential[2], referential[5], referential[8]);
+
+/*****************************************
+ * apply translation along vectors x,y,z *
+ *****************************************/
+
+gamgi_math_vector_scale (x, x, shift[0]);
+gamgi_math_vector_scale (y, y, shift[1]);
+gamgi_math_vector_scale (z, z, shift[2]);
+
+/*******************************************
+ * add x,y,z to get the global translation *
+ *******************************************/
+
+translate[0] = x[0] + y[0] + z[0];
+translate[1] = x[1] + y[1] + z[1];
+translate[2] = x[2] + y[2] + z[2];
+}
+
+static void static_layer (gamgi_object *object, gamgi_layer **layer_old,
+double *shift, double *translate)
+{
+gamgi_layer *layer;
+
+layer = gamgi_engine_find_layer (object);
+if (layer != *layer_old)
+  {
+  *layer_old = layer;
+  static_translate (layer, shift, translate);
+  }
+}
+
 void gamgi_mesa_translate_text (gamgi_text *text, double *translate)
 {
 gamgi_dlist *dlist;
@@ -494,7 +537,6 @@ while (dlist != NULL)
 
 void gamgi_mesa_translate_object (gamgi_object *object, double *translate)
 {
-gamgi_group *group;
 gamgi_plane *plane;
 gamgi_direction *direction;
 
@@ -519,26 +561,18 @@ switch (object->class)
 
   case GAMGI_ENGINE_DIRECTION:
   direction = GAMGI_CAST_DIRECTION object;
-  if (direction->autonomy == GAMGI_GTK_NONE)
-    gamgi_mesa_translate_object (object->object, translate);
-  else
+  if (direction->type == GAMGI_PHYS_LINE)
     gamgi_mesa_translate_direction (direction, translate);
   break;
 
   case GAMGI_ENGINE_PLANE:
   plane = GAMGI_CAST_PLANE object;
-  if (plane->autonomy == GAMGI_GTK_NONE)
-    gamgi_mesa_translate_object (object->object, translate);
-  else
+  if (plane->type == GAMGI_PHYS_POLYGON)
     gamgi_mesa_translate_plane (plane, translate);
   break;
 
   case GAMGI_ENGINE_GROUP:
-  group = GAMGI_CAST_GROUP object;
-  if (group->autonomy == GAMGI_GTK_NONE)
-    gamgi_mesa_translate_object (object->object, translate);
-  else
-    gamgi_mesa_translate_group (group, translate);
+  gamgi_mesa_translate_group (GAMGI_CAST_GROUP object, translate);
   break;
 
   case GAMGI_ENGINE_MOLECULE:
@@ -583,10 +617,267 @@ switch (object->class)
 
 }
 
-void gamgi_mesa_translate_out (gamgi_layer *layer, double *translate)
+void gamgi_mesa_translate_text_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_text *text;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->texts; dlist != NULL; dlist = dlist->next)
+  {
+  text = GAMGI_CAST_TEXT dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT text, &layer, shift, translate);
+  gamgi_mesa_translate_text (text, translate);
+  }
+}
+
+void gamgi_mesa_translate_orbital_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_orbital *orbital;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->orbitals; dlist != NULL; dlist = dlist->next)
+  {
+  orbital = GAMGI_CAST_ORBITAL dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT orbital, &layer, shift, translate);
+  gamgi_mesa_translate_orbital (orbital, translate);
+  }
+}
+
+void gamgi_mesa_translate_bond_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_bond *bond;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->bonds; dlist != NULL; dlist = dlist->next)
+  { 
+  bond = GAMGI_CAST_BOND dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT bond, &layer, shift, translate);
+  gamgi_mesa_translate_out_bond (bond, translate);
+  gamgi_mesa_translate_bond (bond, translate);
+  } 
+}
+
+void gamgi_mesa_translate_atom_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_atom *atom;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->atoms; dlist != NULL; dlist = dlist->next)
+  {
+  atom = GAMGI_CAST_ATOM dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT atom, &layer, shift, translate);
+  gamgi_mesa_translate_atom (atom, translate);
+  }
+}
+
+void gamgi_mesa_translate_direction_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_direction *direction;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->directions; dlist != NULL; dlist = dlist->next)
+  { 
+  direction = GAMGI_CAST_DIRECTION dlist->data;
+  if (direction->type != GAMGI_PHYS_LINE) continue;
+
+  static_layer (GAMGI_CAST_OBJECT direction, &layer, shift, translate);
+  gamgi_mesa_translate_direction (direction, translate);
+  }
+}
+
+void gamgi_mesa_translate_plane_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_plane *plane;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->planes; dlist != NULL; dlist = dlist->next)
+  {
+  plane = GAMGI_CAST_PLANE dlist->data;
+  if (plane->type != GAMGI_PHYS_POLYGON) continue;
+
+  static_layer (GAMGI_CAST_OBJECT plane, &layer, shift, translate);
+  gamgi_mesa_translate_plane (plane, translate);
+  }
+}
+
+void gamgi_mesa_translate_group_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_group *group;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->groups; dlist != NULL; dlist = dlist->next)
+  {
+  group = GAMGI_CAST_GROUP dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT group, &layer, shift, translate);
+  gamgi_mesa_translate_group (group, translate);
+  }
+}
+
+void gamgi_mesa_translate_molecule_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_molecule *molecule;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->molecules; dlist != NULL; dlist = dlist->next)
+  {
+  molecule = GAMGI_CAST_MOLECULE dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT molecule, &layer, shift, translate);
+  gamgi_mesa_translate_molecule (molecule, translate);
+  }
+}
+
+void gamgi_mesa_translate_cluster_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_cluster *cluster;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->clusters; dlist != NULL; dlist = dlist->next)
+  {
+  cluster = GAMGI_CAST_CLUSTER dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT cluster, &layer, shift, translate);
+  gamgi_mesa_translate_cluster (cluster, translate);
+  }
+}
+
+void gamgi_mesa_translate_cell_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_cell *cell;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->cells; dlist != NULL; dlist = dlist->next)
+  {
+  cell = GAMGI_CAST_CELL dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT cell, &layer, shift, translate);
+  gamgi_mesa_translate_cell (cell, translate);
+  }
+}
+
+void gamgi_mesa_translate_arrow_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_arrow *arrow;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->arrows; dlist != NULL; dlist = dlist->next)
+  {
+  arrow = GAMGI_CAST_ARROW dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT arrow, &layer, shift, translate);
+  gamgi_mesa_translate_arrow (arrow, translate);
+  }
+}
+
+void gamgi_mesa_translate_shape_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_shape *shape;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->shapes; dlist != NULL; dlist = dlist->next)
+  {
+  shape = GAMGI_CAST_SHAPE dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT shape, &layer, shift, translate);
+  gamgi_mesa_translate_shape (shape, translate);
+  }
+}
+
+void gamgi_mesa_translate_graph_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_graph *graph;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->graphs; dlist != NULL; dlist = dlist->next)
+  {
+  graph = GAMGI_CAST_GRAPH dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT graph, &layer, shift, translate);
+  gamgi_mesa_translate_graph (graph, translate);
+  }
+}
+
+void gamgi_mesa_translate_assembly_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_assembly *assembly;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->assemblys; dlist != NULL; dlist = dlist->next)
+  {
+  assembly = GAMGI_CAST_ASSEMBLY dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT assembly, &layer, shift, translate);
+  gamgi_mesa_translate_assembly (assembly, translate);
+  }
+}
+
+void gamgi_mesa_translate_light_list (double *shift)
+{
+gamgi_layer *layer = NULL;
+gamgi_light *light;
+gamgi_dlist *dlist;
+double translate[3];
+
+for (dlist = gamgi->lights; dlist != NULL; dlist = dlist->next)
+  {
+  light = GAMGI_CAST_LIGHT dlist->data;
+
+  static_layer (GAMGI_CAST_OBJECT light, &layer, shift, translate);
+  gamgi_mesa_translate_light (light, translate);
+  }
+}
+
+void gamgi_mesa_translate_layer_in (gamgi_layer *layer, 
+gamgi_object *object, double *shift)
+{
+double translate[3];
+
+/****************************************************
+ * get translation as function of layer positioning *
+ ****************************************************/
+
+static_translate (layer, shift, translate);
+gamgi_mesa_translate_object (object, translate);
+}
+
+void gamgi_mesa_translate_layer_out (gamgi_layer *layer, double *shift)
 {
 double *referential;
 double x[3], y[3], z[3];
+double translate[3];
 
 referential = layer->referential;
 gamgi_math_vector_absolute (x, referential[0], referential[3], referential[6]);
@@ -597,9 +888,9 @@ gamgi_math_vector_absolute (z, referential[2], referential[5], referential[8]);
  * apply translation along vectors x,y,z *
  *****************************************/
 
-gamgi_math_vector_scale (x, x, translate[0]);
-gamgi_math_vector_scale (y, y, translate[1]);
-gamgi_math_vector_scale (z, z, translate[2]);
+gamgi_math_vector_scale (x, x, shift[0]);
+gamgi_math_vector_scale (y, y, shift[1]);
+gamgi_math_vector_scale (z, z, shift[2]);
 
 /*******************************************
  * add x,y,z to get the global translation *
@@ -624,94 +915,219 @@ gamgi_math_vector_add (layer->center, translate, layer->center);
 gamgi_math_vector_add (layer->center, translate, layer->center);
 }
 
-void gamgi_mesa_translate_in (gamgi_layer *layer,
-gamgi_object *object, double *translate)
+void gamgi_mesa_translate_layer_list (double *shift)
 {
-double *referential;
-double x[3], y[3], z[3];
+gamgi_window *window;
+gamgi_layer *layer;
+gamgi_dlist *dlist;
 
-referential = layer->referential;
-gamgi_math_vector_absolute (x, referential[0], referential[3], referential[6]);
-gamgi_math_vector_absolute (y, referential[1], referential[4], referential[7]);
-gamgi_math_vector_absolute (z, referential[2], referential[5], referential[8]);
-
-/*****************************************
- * apply translation along vectors x,y,z *
- *****************************************/
-
-gamgi_math_vector_scale (x, x, translate[0]);
-gamgi_math_vector_scale (y, y, translate[1]);
-gamgi_math_vector_scale (z, z, translate[2]);
-
-/*******************************************
- * add x,y,z to get the global translation *
- *******************************************/
-
-translate[0] = x[0] + y[0] + z[0];
-translate[1] = x[1] + y[1] + z[1];
-translate[2] = x[2] + y[2] + z[2];
-
-gamgi_mesa_translate_object (object, translate);
+for (dlist = gamgi->layers; dlist != NULL; dlist = dlist->next)
+  {
+  layer = GAMGI_CAST_LAYER dlist->data;
+  window = GAMGI_CAST_WINDOW layer->object.object;
+  if (window->axes == FALSE)
+    gamgi_mesa_translate_layer_in (layer, GAMGI_CAST_OBJECT layer, shift);
+  else
+    gamgi_mesa_translate_layer_out (layer, shift);
+  }
 }
 
-void gamgi_mesa_translate (gamgi_window *window,
-gamgi_object *object, double *translate)
+void gamgi_mesa_translate_window_in (gamgi_window *window, double *shift)
 {
 gamgi_layer *layer;
 gamgi_dlist *dlist;
 
-/***********************
- * translate view axes *
- ***********************/
+/************************
+ * translate all layers *
+ ************************/
 
-if (window->axes == TRUE)
+for (dlist = window->layer_start; dlist != NULL; dlist = dlist->next)
   {
-  /************************
-   * in all window layers *
-   ************************/
+  layer = GAMGI_CAST_LAYER dlist->data;
+  gamgi_mesa_translate_layer_in (layer, GAMGI_CAST_OBJECT layer, shift);
+  }
+}
 
-  if (object == GAMGI_CAST_OBJECT window)
-    {
-    for (dlist = window->layer_start; dlist != NULL; dlist = dlist->next)
-      {
-      layer = GAMGI_CAST_LAYER dlist->data;
-      gamgi_mesa_translate_out (layer, translate);
-      }
-    }
+void gamgi_mesa_translate_window_out (gamgi_window *window, double *shift)
+{
+gamgi_layer *layer;
+gamgi_dlist *dlist;
 
-  /*************************
-   * just in current layer *
-   *************************/
+/************************
+ * translate all layers *
+ ************************/
 
-  else gamgi_mesa_translate_out (window->layer, translate);
+for (dlist = window->layer_start; dlist != NULL; dlist = dlist->next)
+  {
+  layer = GAMGI_CAST_LAYER dlist->data;
+  gamgi_mesa_translate_layer_out (layer, shift);
+  }
+}
+
+void gamgi_mesa_translate_window_list (double *shift)
+{
+gamgi_window *window;
+gamgi_dlist *dlist;
+
+for (dlist = gamgi->windows; dlist != NULL; dlist = dlist->next)
+  {
+  window = GAMGI_CAST_WINDOW dlist->data;
+
+  if (window->axes == FALSE)
+    gamgi_mesa_translate_window_in (window, shift);
+  else
+    gamgi_mesa_translate_window_out (window, shift);
+  }
+}
+
+void gamgi_mesa_translate_gamgi_list (double *shift)
+{
+gamgi_window *window;
+
+for (window = gamgi->window_start; window != NULL; window = window->next)
+  {
+  if (window->axes == FALSE)
+    gamgi_mesa_translate_window_in (window, shift);
+  else
+    gamgi_mesa_translate_window_out (window, shift);
+  }
+}
+
+void gamgi_mesa_translate_list (double *shift)
+{
+switch (gamgi->focus)
+  {
+  case GAMGI_ENGINE_TEXT:
+  gamgi_mesa_translate_text_list (shift);
+  break;
+
+  case GAMGI_ENGINE_ORBITAL:
+  gamgi_mesa_translate_orbital_list (shift);
+  break;
+
+  case GAMGI_ENGINE_BOND:
+  gamgi_mesa_translate_bond_list (shift);
+  break;
+
+  case GAMGI_ENGINE_ATOM:
+  gamgi_mesa_translate_atom_list (shift);
+  break;
+
+  case GAMGI_ENGINE_DIRECTION:
+  gamgi_mesa_translate_direction_list (shift);
+  break;
+
+  case GAMGI_ENGINE_PLANE:
+  gamgi_mesa_translate_plane_list (shift);
+  break;
+
+  case GAMGI_ENGINE_GROUP:
+  gamgi_mesa_translate_group_list (shift);
+  break;
+
+  case GAMGI_ENGINE_MOLECULE:
+  gamgi_mesa_translate_molecule_list (shift);
+  break;
+
+  case GAMGI_ENGINE_CLUSTER:
+  gamgi_mesa_translate_cluster_list (shift);
+  break;
+
+  case GAMGI_ENGINE_CELL:
+  gamgi_mesa_translate_cell_list (shift);
+  break;
+
+  case GAMGI_ENGINE_ARROW:
+  gamgi_mesa_translate_arrow_list (shift);
+  break;
+
+  case GAMGI_ENGINE_SHAPE:
+  gamgi_mesa_translate_shape_list (shift);
+  break;
+
+  case GAMGI_ENGINE_GRAPH:
+  gamgi_mesa_translate_graph_list (shift);
+  break;
+
+  case GAMGI_ENGINE_ASSEMBLY:
+  gamgi_mesa_translate_assembly_list (shift);
+  break;
+
+  case GAMGI_ENGINE_LIGHT:
+  gamgi_mesa_translate_light_list (shift);
+  break;
+
+  case GAMGI_ENGINE_LAYER:
+  gamgi_mesa_translate_layer_list (shift);
+  break;
+
+  case GAMGI_ENGINE_WINDOW:
+  gamgi_mesa_translate_window_list (shift);
+  break;
+
+  case GAMGI_ENGINE_GAMGI:
+  gamgi_mesa_translate_gamgi_list (shift);
+  break;
+
+  default:
+  return;
   }
 
-/*********************
- * translate objects *
- *********************/
+/****************************
+ * redraw all OpenGL images *
+ ****************************/
 
-if (window->axes == FALSE)
+gamgi_mesa_draw_gamgi ();
+}
+
+void gamgi_mesa_translate (gamgi_window *window,
+gamgi_object *object, double *shift)
+{
+/****************************************************************
+ * translate list of objects, including the Gamgi global object *
+ ****************************************************************/
+
+if (gamgi->focus != FALSE)
+  { gamgi_mesa_translate_list (shift); return; }
+  
+/***********************************************
+ * translate object with focus, which can be a *
+ * window, a layer or any other local object   *
+ ***********************************************/
+
+switch (object->class)
   {
-  /************************
-   * in all window layers *
-   ************************/
+  /******************************************
+   * translate all layers in current window *
+   ******************************************/
 
-  if (object == GAMGI_CAST_OBJECT window)
-    {
-    for (dlist = window->layer_start; dlist != NULL; dlist = dlist->next)
-      {
-      layer = GAMGI_CAST_LAYER dlist->data;
-      gamgi_mesa_translate_in (layer, GAMGI_CAST_OBJECT layer, translate);
-      }
-    }
+  case GAMGI_ENGINE_WINDOW:
+  if (window->axes == FALSE)
+    gamgi_mesa_translate_window_in (window, shift);
+  else
+    gamgi_mesa_translate_window_out (window, shift);
+  break;
 
-  /*************************
-   * just in current layer *
-   *************************/
+  /*********************************************
+   * translate current layer in current window *
+   *********************************************/
 
-  else gamgi_mesa_translate_in (window->layer, object, translate);
+  case GAMGI_ENGINE_LAYER:
+  if (window->axes == FALSE)
+    gamgi_mesa_translate_layer_in (window->layer, object, shift);
+  else
+    gamgi_mesa_translate_layer_out (window->layer, shift);
+  break;
+
+  /*********************************************
+   * translate current object in current layer *
+   *********************************************/
+
+  default:
+  gamgi_mesa_translate_layer_in (window->layer, object, shift);
+  break;
   }
-
+  
 /***********************
  * redraw OpenGL image *
  ***********************/
