@@ -23,6 +23,7 @@
 #include "gamgi_engine_link.h"
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_dlist.h"
+#include "gamgi_engine_filter.h"
 #include "gamgi_engine_find.h"
 #include "gamgi_engine_remove.h"
 #include "gamgi_engine_array.h"
@@ -268,40 +269,8 @@ while (dlist != NULL)
 return darray;
 }
 
-static void static_link (gamgi_direction *direction,
-double *normal, gamgi_dlist *dlist)
-{
-gamgi_atom *atom;
-gamgi_dlist *dlist_a;
-double r[3], s[3];
-double length;
-
-/**************************************************************
- * link atoms to direction: this is used in atomic directions *
- * (AUTOMATIC,AUTONOMOUS) and crystalographic directions      *
- * (AUTONOMOUS) so directions know where are their atoms      *
- **************************************************************/
-
-for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
-  {
-  atom = GAMGI_CAST_ATOM dlist_a->data;
-
-  gamgi_math_vector_sub (atom->position, direction->center, r);
-  length = gamgi_math_vector_dot (r, normal);
-  gamgi_math_vector_scale (normal, s, length);
-  gamgi_math_vector_sub (r, s, r);
-  length = gamgi_math_vector_length (r);
-
-  if (fabs (length) < direction->thickness)
-    {
-    gamgi_engine_unlink_atom (atom);
-    gamgi_engine_link_atom_direction (atom, direction);
-    }
-  }
-}
-
 static void static_copy (gamgi_direction *direction,
-double *normal, gamgi_dlist *atoms)
+double *normal, gamgi_dlist *start)
 {
 gamgi_atom *atom, *atom_new;
 gamgi_dlist *dlist;
@@ -313,7 +282,7 @@ double length;
  * in parent that are closer than thickness *
  ********************************************/
 
-for (dlist = atoms; dlist != NULL; dlist = dlist->next)
+for (dlist = start; dlist != NULL; dlist = dlist->next)
   {
   atom = GAMGI_CAST_ATOM dlist->data;
 
@@ -334,10 +303,41 @@ for (dlist = atoms; dlist != NULL; dlist = dlist->next)
  * clean bonds in parent object *
  ********************************/
 
-for (dlist = atoms; dlist != NULL; dlist = dlist->next)
+for (dlist = start; dlist != NULL; dlist = dlist->next)
   gamgi_chem_atom_clean (GAMGI_CAST_ATOM dlist->data);
 }
 
+static void static_link (gamgi_direction *direction, double *normal,
+gamgi_dlist *start)
+{
+gamgi_atom *atom;
+gamgi_dlist *dlist;
+double r[3], s[3];
+double length;
+
+/****************************************************
+ * link atoms to direction: this is used in         *
+ * atomic directions and crystalographic directions *
+ ****************************************************/
+
+for (dlist = start; dlist != NULL; dlist = dlist->next)
+  {
+  atom = GAMGI_CAST_ATOM dlist->data;
+
+  gamgi_math_vector_sub (atom->position, direction->center, r);
+  length = gamgi_math_vector_dot (r, normal);
+  gamgi_math_vector_scale (normal, s, length);
+  gamgi_math_vector_sub (r, s, r);
+  length = gamgi_math_vector_length (r);
+
+  if (fabs (length) < direction->thickness)
+    {
+    gamgi_engine_unlink_atom (atom);
+    gamgi_engine_link_atom_direction (atom, direction);
+    }
+  }
+}
+
 static int static_order (int *hkl, gamgi_cell *cell, int step)
 {
 int order;
@@ -356,12 +356,7 @@ plane->hkl[1] = hkl[1];
 plane->hkl[2] = hkl[2];
 plane->vectors = GAMGI_PHYS_PRIMITIVE;
 
-/*
-order = -static_order (plane, cell, cell->o1, cell->o2, cell->o3);
-*/
-
 order = 0;
-
 do
   {
   order += step;
@@ -441,10 +436,10 @@ inside = gamgi_phys_direction_cell (direction_new, cell);
 if (inside == TRUE || link == TRUE)
   {
   gamgi_engine_link_direction_cell (direction_new, cell);
-  if (direction->autonomy == GAMGI_GTK_PARTIAL)
-    static_link (direction_new, normal, dlist);
-  if (direction->autonomy == GAMGI_GTK_ALL)
+  if (direction->structure == GAMGI_CHEM_STRUCTURE_COPY)
     static_copy (direction_new, normal, dlist);
+  if (direction->structure == GAMGI_CHEM_STRUCTURE_LINK)
+    static_link (direction_new, normal, dlist);
   }
 else gamgi_engine_remove_direction (direction_new);
 
@@ -906,33 +901,12 @@ if (dlist != NULL)
 return FALSE;
 }
 
-gamgi_bool gamgi_phys_direction_compatible (gamgi_atom *atom1, 
-gamgi_atom *atom2)
-{
-gamgi_object *parent;
-
-/***************************************************************
- * check if atom1, atom2 cannot belong to planes or directions *
- ***************************************************************/
-
-parent = atom1->object.object;
-if (parent->class == GAMGI_ENGINE_PLANE || 
-parent->class == GAMGI_ENGINE_DIRECTION) return FALSE;
-
-parent = atom2->object.object;
-if (parent->class == GAMGI_ENGINE_PLANE || 
-parent->class == GAMGI_ENGINE_DIRECTION) return FALSE;
-
-return TRUE;
-}
-
-gamgi_bool gamgi_phys_direction_line (gamgi_atom *atom1,
-gamgi_atom *atom2)
+gamgi_bool gamgi_phys_direction_length (double *begin, double *end)
 {
 double u[3];
 double length;
 
-gamgi_math_vector_sub (atom1->position, atom2->position, u);
+gamgi_math_vector_sub (begin, end, u);
 length = gamgi_math_vector_length (u);
 if (length < GAMGI_MATH_TOLERANCE_LENGTH) return FALSE;
 
@@ -1033,11 +1007,10 @@ static_center (direction);
  * link or copy atoms to direction *
  ***********************************/
 
-if (direction->autonomy == GAMGI_GTK_NONE ||
-direction->autonomy == GAMGI_GTK_PARTIAL)
-  static_link (direction, normal, dlist);
-if (direction->autonomy == GAMGI_GTK_ALL && copy == TRUE)
+if (direction->structure == GAMGI_CHEM_STRUCTURE_COPY)
   static_copy (direction, normal, dlist);
+if (direction->structure == GAMGI_CHEM_STRUCTURE_LINK)
+  static_link (direction, normal, dlist);
 
 /*******************************************
  * rotate the parent object, including     *
@@ -1056,7 +1029,7 @@ while (dlist != NULL)
 }
 
 void gamgi_phys_direction_polytope (int n_neighbours, gamgi_atom **neighbours,
-gamgi_enum autonomy, float red, float green, float blue, gamgi_object *parent,
+gamgi_enum structure, float red, float green, float blue, gamgi_object *parent,
 gamgi_atom *central)
 {
 gamgi_direction *direction;
@@ -1065,8 +1038,6 @@ double unit[9], rotation[9];
 double zero[3], translation[3];
 int i, min, max;
 
-autonomy = GAMGI_GTK_NONE;
-
 /********************************************************
  * link direction and set type before handling rotation *
  ********************************************************/
@@ -1078,7 +1049,6 @@ strcpy (direction->object.name, "Direction");
 
 direction->reference = GAMGI_ENGINE_ATOM;
 direction->type = GAMGI_PHYS_LINE;
-direction->autonomy = autonomy;
 direction->thickness = GAMGI_CHEM_DIRECTION_THICKNESS;
 
 direction->red = red;
@@ -1130,20 +1100,57 @@ gamgi_math_polygon_lines (direction->n_points, &direction->loops,
 &direction->n_loops);
 static_center (direction);
 
-/************************************************
- * copy all neighbours from parent to direction *
- ************************************************/
+/*********************
+ * include structure *
+ *********************/
 
-if (direction->autonomy == GAMGI_GTK_ALL)
+if (structure == GAMGI_CHEM_STRUCTURE_COPY)
   {
+  /**********************************************
+   * copy central, neighbour atoms to group     *
+   *                                            *
+   * clean bonds in central and neighbour atoms *
+   **********************************************/
+
   atom = gamgi_engine_copy_atom (central);
   gamgi_engine_link_atom_direction (atom, direction);
-
   for (i = 0; i < n_neighbours; i++)
     {
     atom = gamgi_engine_copy_atom (neighbours[i]);
     gamgi_engine_link_atom_direction (atom, direction);
     }
+
+  gamgi_chem_atom_clean (central);
+  for (i = 0; i < n_neighbours; i++)
+    gamgi_chem_atom_clean (neighbours[i]);
+  }
+
+if (structure == GAMGI_CHEM_STRUCTURE_LINK)
+  {
+  /******************************************
+   * link central, neighbour atoms to group *
+   ******************************************/
+
+  gamgi_engine_unlink_atom (central);
+  gamgi_engine_link_atom_direction (central, direction);
+  for (i = 0; i < n_neighbours; i++)
+    {
+    gamgi_engine_unlink_atom (neighbours[i]);
+    gamgi_engine_link_atom_direction (neighbours[i], direction);
+    }
+  }
+
+/************************************************
+ * copy all neighbours from parent to direction *
+ ************************************************/
+
+atom = gamgi_engine_copy_atom (central);
+gamgi_engine_link_atom_direction (atom, direction);
+
+for (i = 0; i < n_neighbours; i++)
+  {
+  atom = gamgi_engine_copy_atom (neighbours[i]);
+  gamgi_engine_link_atom_direction (atom, direction);
   }
 
 /*******************************************
@@ -1169,21 +1176,20 @@ int node[3];
 int i, j;
 gamgi_bool link;
 
-if (direction->autonomy != GAMGI_GTK_NONE)
-  {
-  /*****************************************************
-   * link atoms to direction: 1) get direction normal, *
-   * rotated according to the cell orientation         *
-   * 2) get list of atoms belonging to the cell        *
-   *****************************************************/
+/*****************************************************
+ * link atoms to direction: 1) get direction normal, *
+ * rotated according to the cell orientation         *
+ * 2) get list of atoms belonging to the cell        *
+ *****************************************************/
 
-  gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
-  gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, vector);
-  gamgi_math_matrix_vector (rotate, vector, normal);
-  gamgi_math_vector_normal (normal);
+gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
+gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, vector);
+gamgi_math_matrix_vector (rotate, vector, normal);
+gamgi_math_vector_normal (normal);
 
-  dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
-  }
+dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
+dlist = gamgi_engine_filter_atom (dlist, direction->filter,
+GAMGI_ENGINE_DIRECTION, GAMGI_CAST_OBJECT cell);
 
 /*******************************************
  * convert plane indices to primitive axes *
@@ -1270,39 +1276,36 @@ gamgi_dlist *dlist = NULL;
 double rotate[9];
 double vector[3], normal[3];
 
-/****************************************
- * build new direction and link to cell *
- ****************************************/
+/*********************************************
+ * 1) build new direction and link to cell   *
+ * 2) get normalized direction vector,       *
+ * rotated according to the cell orientation *
+ *********************************************/
 
 gamgi_phys_direction_cell (direction, cell);
 gamgi_engine_link_direction_cell (direction, cell);
 
-if (direction->autonomy != GAMGI_GTK_NONE)
-  {
-  /**********************************************
-   * link atoms to direction: 1) get normalized *
-   * direction vector, rotated according to the *
-   * cell orientation; 2) get list of atoms     *
-   * belonging to the cell; 3) link or copy     *
-   * atoms; 4) free list of atoms.              *
-   **********************************************/
+gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
+gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, vector);
+gamgi_math_matrix_vector (rotate, vector, normal);
+gamgi_math_vector_normal (normal);
 
-  gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
-  gamgi_phys_direction_vector (cell, direction->uvw, direction->vectors, vector);
-  gamgi_math_matrix_vector (rotate, vector, normal);
-  gamgi_math_vector_normal (normal);
+/*************************************************
+ * 1) get list of atoms belonging to the cell;   *
+ * 2) apply structure policy; 3) free atom list. *
+ *************************************************/
 
-  dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
-  if (direction->autonomy == GAMGI_GTK_PARTIAL)
-    static_link (direction, normal, dlist);
-  if (direction->autonomy == GAMGI_GTK_ALL)
-    static_copy (direction, normal, dlist);
+dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
+dlist = gamgi_engine_filter_atom (dlist, direction->filter,
+GAMGI_ENGINE_DIRECTION, GAMGI_CAST_OBJECT cell);
 
-  while (dlist != NULL)
-    dlist = gamgi_engine_dlist_remove_start (dlist);
-  }
+if (direction->structure == GAMGI_CHEM_STRUCTURE_COPY)
+  static_copy (direction, normal, dlist);
+if (direction->structure == GAMGI_CHEM_STRUCTURE_LINK)
+  static_link (direction, normal, dlist);
+
+while (dlist != NULL)
+  dlist = gamgi_engine_dlist_remove_start (dlist);
 }
 
 void gamgi_phys_direction_projection (gamgi_direction *direction,
@@ -1353,3 +1356,27 @@ if (trace == TRUE)
   }
 
 }
+
+void gamgi_phys_direction_line (gamgi_direction *direction, double *points)
+{
+int i;
+
+/********************************
+ * build points array: 2 points *
+ ********************************/
+
+direction->points = (double *) malloc (sizeof (double) * 6);
+for (i = 0; i < 6; i++) direction->points[i] = points[i];
+direction->n_points = 2;
+
+/*****************************
+ * build loops array: 1 line *
+ *****************************/
+
+direction->loops = (int *) malloc (sizeof (int) * 3);
+direction->loops[0] = 1;
+direction->loops[1] = 0;
+direction->loops[2] = 1;
+
+direction->n_loops = 3;
+}
