@@ -23,6 +23,7 @@
 #include "gamgi_engine_link.h"
 #include "gamgi_engine_list.h"
 #include "gamgi_engine_dlist.h"
+#include "gamgi_engine_filter.h"
 #include "gamgi_engine_find.h"
 #include "gamgi_engine_remove.h"
 #include "gamgi_engine_array.h"
@@ -43,12 +44,11 @@
 #include "gamgi_phys_projection.h"
 #include "gamgi_phys_reciprocal.h"
 
-static void static_create (gamgi_cell *cell, double reciprocal, 
-gamgi_enum vectors, int h, int k, int l, double *points, double *origin)
+static void static_create (gamgi_cell *cell,
+gamgi_enum vectors, int h, int k, int l, double *origin)
 {
 gamgi_plane *plane;
 char token[GAMGI_ENGINE_TOKEN];
-int n;
 
 plane = gamgi_engine_create_plane ();
 gamgi_engine_start_plane (plane);
@@ -61,32 +61,21 @@ plane->vectors = vectors;
 plane->hkl[0] = h;
 plane->hkl[1] = k;
 plane->hkl[2] = l;
-plane->reciprocal = reciprocal;
 
 gamgi_math_vector_copy (origin, plane->origin);
-
-n = 1;
-plane->points = (double *) malloc (n * 3 * sizeof (double));
-gamgi_math_vector_copy (points, plane->points);
-plane->n_points = n;
-
-n = 2;
-plane->loops = (int *) malloc (n * sizeof (int));
-plane->loops[0] = 1;
-plane->loops[1] = 0;
-plane->n_loops = n;
+gamgi_phys_reciprocal_points (plane);
 
 /************************
  * plane representation *
  ************************/
 
-plane->type = GAMGI_PHYS_RECIPROCAL;
+plane->type = GAMGI_PHYS_VECTOR;
 
 gamgi_engine_link_plane_cell (plane, cell);
 }
 
-static void static_create_all (gamgi_cell *cell, double reciprocal, 
-int *index, double *transformation, double *orientation)
+static void static_create_all (gamgi_cell *cell, int *index,
+double *transformation, double *orientation)
 {
 double u[3], v[3], translate[3];
 int n, h, k, l;
@@ -129,7 +118,7 @@ for (n = 0; n < cell->n_nodes; n++)
   if (gamgi_phys_direction_zero (index + 3*n) == FALSE) 
     {
     gamgi_math_vector_add (v, translate, u);
-    static_create (cell, reciprocal, vectors, h, k, l, cell->points + 3*n, u);
+    static_create (cell, vectors, h, k, l, u);
     }
   }
 }
@@ -901,37 +890,8 @@ for (i = 0; i < n_neighbours; i++)
 return darray;
 }
 
-static void static_link (gamgi_plane *plane,
-double *normal, gamgi_dlist *dlist)
-{
-gamgi_atom *atom;
-gamgi_dlist *dlist_a;
-double r[3];
-double length;
-
-/******************************************************
- * link atoms to plane: this is used in atomic planes *
- * (AUTOMATIC,AUTONOMOUS) and crystalographic planes  *
- * (AUTONOMOUS) so planes know where are their atoms  *
- ******************************************************/
-
-for (dlist_a = dlist; dlist_a != NULL; dlist_a = dlist_a->next)
-  {
-  atom = GAMGI_CAST_ATOM dlist_a->data;
-
-  gamgi_math_vector_sub (atom->position, plane->center, r);
-  length = gamgi_math_vector_dot (r, normal);
-
-  if (fabs (length) < plane->thickness)
-    {
-    gamgi_engine_unlink_atom (atom);
-    gamgi_engine_link_atom_plane (atom, plane);
-    }
-  }
-}
-
-static void static_copy (gamgi_plane *plane,
-double *normal, gamgi_dlist *atoms)
+static void static_copy (gamgi_plane *plane, double *normal,
+gamgi_dlist *start)
 {
 gamgi_atom *atom, *atom_new;
 gamgi_dlist *dlist;
@@ -943,7 +903,7 @@ double length;
  * in parent that are closer than thickness *
  ********************************************/
 
-for (dlist = atoms; dlist != NULL; dlist = dlist->next)
+for (dlist = start; dlist != NULL; dlist = dlist->next)
   {
   atom = GAMGI_CAST_ATOM dlist->data;
 
@@ -961,9 +921,36 @@ for (dlist = atoms; dlist != NULL; dlist = dlist->next)
  * clean bonds in parent object *
  ********************************/
 
-for (dlist = atoms; dlist != NULL; dlist = dlist->next)
+for (dlist = start; dlist != NULL; dlist = dlist->next)
   gamgi_chem_atom_clean (GAMGI_CAST_ATOM dlist->data);
-    
+}
+
+static void static_link (gamgi_plane *plane, double *normal,
+gamgi_dlist *start)
+{
+gamgi_atom *atom;
+gamgi_dlist *dlist;
+double r[3];
+double length;
+
+/********************************************
+ * link atoms to plane: this is used in     *
+ * atomic planes and crystalographic planes *
+ ********************************************/
+
+for (dlist = start; dlist != NULL; dlist = dlist->next)
+  {
+  atom = GAMGI_CAST_ATOM dlist->data;
+
+  gamgi_math_vector_sub (atom->position, plane->center, r);
+  length = gamgi_math_vector_dot (r, normal);
+
+  if (fabs (length) < plane->thickness)
+    {
+    gamgi_engine_unlink_atom (atom);
+    gamgi_engine_link_atom_plane (atom, plane);
+    }
+  }
 }
 
 static gamgi_bool static_normal (gamgi_plane *plane, double *normal)
@@ -1021,17 +1008,17 @@ plane_new->order = order;
 
 inside = gamgi_phys_plane_cell (plane_new, cell);
 
-/*********************************************************
- * link options: link plane to cell, link atoms to plane *
- *********************************************************/
+/*****************************************************
+ * link plane to cell, copy,link,none atoms to plane *
+ *****************************************************/
 
 if (inside == TRUE || link == TRUE)
   {
   gamgi_engine_link_plane_cell (plane_new, cell);
-  if (plane->autonomy == GAMGI_GTK_PARTIAL)
-    static_link (plane_new, normal, dlist);
-  if (plane->autonomy == GAMGI_GTK_ALL)
+  if (plane->structure == GAMGI_CHEM_STRUCTURE_COPY)
     static_copy (plane_new, normal, dlist);
+  if (plane->structure == GAMGI_CHEM_STRUCTURE_LINK)
+    static_link (plane_new, normal, dlist);
   }
 else gamgi_engine_remove_plane (plane_new);
 
@@ -1367,7 +1354,7 @@ switch (lattice)
 }
 
 void gamgi_phys_plane_reciprocal (gamgi_cell *cell,
-double reciprocal, double *transformation, double *orientation)
+double *transformation, double *orientation)
 {
 int *index;
 int offset[3] = {0};
@@ -1380,7 +1367,7 @@ index = static_index_nodes (cell);
 static_index_origin (cell, offset);
 static_index_translate (cell, offset, index);
 
-static_create_all (cell, reciprocal, index, transformation, orientation);
+static_create_all (cell, index, transformation, orientation);
 
 free (index);
 }
@@ -1613,30 +1600,6 @@ if (dlist != NULL)
 return FALSE;
 }
 
-gamgi_bool gamgi_phys_plane_compatible (gamgi_atom *atom1, 
-gamgi_atom *atom2, gamgi_atom *atom3)
-{
-gamgi_object *parent;
-
-/***************************************************************
- * check if atom1, atom2, atom3 belong to planes or directions *
- ***************************************************************/
-
-parent = atom1->object.object;
-if (parent->class == GAMGI_ENGINE_PLANE ||
-parent->class == GAMGI_ENGINE_DIRECTION) return FALSE;
-
-parent = atom2->object.object;
-if (parent->class == GAMGI_ENGINE_PLANE ||
-parent->class == GAMGI_ENGINE_DIRECTION) return FALSE;
-
-parent = atom3->object.object;
-if (parent->class == GAMGI_ENGINE_PLANE ||
-parent->class == GAMGI_ENGINE_DIRECTION) return FALSE;
-
-return TRUE;
-}
-
 gamgi_bool gamgi_phys_plane_polygon (gamgi_atom *atom1,
 gamgi_atom *atom2, gamgi_atom *atom3)
 {
@@ -1685,7 +1648,7 @@ return start;
 }
 
 void gamgi_phys_plane_atoms (gamgi_plane *plane, gamgi_atom *atom1, 
-gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist, gamgi_bool copy)
+gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist)
 {
 gamgi_darray *darray;
 double unit[9], rotation[9];
@@ -1746,14 +1709,14 @@ gamgi_engine_darray_copy_remove (darray, &plane->points, &plane->n_points);
 gamgi_math_polygon_loops (plane->n_points, &plane->loops, &plane->n_loops);
 static_center (plane);
 
-/*******************************
- * link or copy atoms to plane *
- *******************************/
+/*********************************
+ * link,copy,none atoms to plane *
+ *********************************/
 
-if (plane->autonomy == GAMGI_GTK_NONE || plane->autonomy == GAMGI_GTK_PARTIAL)
-  static_link (plane, normal, dlist);
-if (plane->autonomy == GAMGI_GTK_ALL && copy == TRUE)
+if (plane->structure == GAMGI_CHEM_STRUCTURE_COPY)
   static_copy (plane, normal, dlist);
+if (plane->structure == GAMGI_CHEM_STRUCTURE_LINK)
+  static_link (plane, normal, dlist);
 
 /***************************************
  * rotate the parent object, including *
@@ -1772,7 +1735,7 @@ while (dlist != NULL)
 }
 
 void gamgi_phys_plane_polytope (int n_neighbours, gamgi_atom **neighbours,
-gamgi_enum autonomy, float red, float green, float blue, gamgi_object *parent,
+gamgi_enum structure, float red, float green, float blue, gamgi_object *parent,
 gamgi_atom *central)
 {
 gamgi_plane *plane;
@@ -1782,11 +1745,9 @@ double unit[9], rotation[9];
 double zero[3], normal[3], translation[3];
 int i;
 
-autonomy = GAMGI_GTK_NONE;
-
-/********************************************************
+/****************************************************
  * link plane and set type before handling rotation *
- ********************************************************/
+ ****************************************************/
 
 plane = gamgi_engine_create_plane ();
 gamgi_engine_start_plane (plane);
@@ -1795,7 +1756,7 @@ strcpy (plane->object.name, "Plane");
 
 plane->reference = GAMGI_ENGINE_ATOM;
 plane->type = GAMGI_PHYS_POLYGON;
-plane->autonomy = autonomy;
+plane->structure = structure;
 plane->thickness = GAMGI_CHEM_PLANE_THICKNESS;
 
 plane->red = red;
@@ -1855,20 +1816,44 @@ gamgi_engine_darray_copy_remove (darray, &plane->points, &plane->n_points);
 gamgi_math_polygon_loops (plane->n_points, &plane->loops, &plane->n_loops);
 static_center (plane);
 
-/********************************************
- * copy all neighbours from parent to plane *
- ********************************************/
+/*********************
+ * include structure *
+ *********************/
 
-if (plane->autonomy == GAMGI_GTK_ALL)
+if (structure == GAMGI_CHEM_STRUCTURE_COPY)
   {
+  /**********************************************
+   * copy central, neighbour atoms to group     *
+   *                                            *
+   * clean bonds in central and neighbour atoms *
+   **********************************************/
+
   atom = gamgi_engine_copy_atom (central);
   gamgi_engine_link_atom_plane (atom, plane);
-
   for (i = 0; i < n_neighbours; i++)
     {
     atom = gamgi_engine_copy_atom (neighbours[i]);
     gamgi_engine_link_atom_plane (atom, plane);
     }
+
+  gamgi_chem_atom_clean (central);
+  for (i = 0; i < n_neighbours; i++)
+    gamgi_chem_atom_clean (neighbours[i]);
+  }
+
+if (structure == GAMGI_CHEM_STRUCTURE_LINK)
+  {
+  /******************************************
+   * link central, neighbour atoms to group *
+   ******************************************/
+
+  gamgi_engine_unlink_atom (central);
+  gamgi_engine_link_atom_plane (central, plane);
+  for (i = 0; i < n_neighbours; i++)
+    {
+    gamgi_engine_unlink_atom (neighbours[i]);
+    gamgi_engine_link_atom_plane (neighbours[i], plane);
+    }
   }
 
 /***************************************
@@ -1887,37 +1872,37 @@ gamgi_dlist *dlist = NULL;
 double rotate[9];
 double vector[3], normal[3];
 
-if (plane->autonomy != GAMGI_GTK_NONE)
-  {
-  dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_PLANE);
-  dlist = gamgi_engine_dlist_atom_remove_class (dlist, GAMGI_ENGINE_DIRECTION);
+/*******************************************
+ * get list of atoms belonging to the cell *
+ *******************************************/
 
-  /**********************************************
-   * link atoms to plane: 1) get plane normal,  *
-   * rotated according to the cell orientation  *
-   * 2) get list of atoms belonging to the cell *
-   **********************************************/
+dlist = gamgi_engine_dlist_atom_object (GAMGI_CAST_OBJECT cell, NULL);
+dlist = gamgi_engine_filter_atom (dlist, plane->filter,
+GAMGI_ENGINE_PLANE, GAMGI_CAST_OBJECT cell);
 
-  gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
-  gamgi_phys_plane_vector (cell, plane->hkl, plane->vectors, vector);
-  gamgi_math_matrix_vector (rotate, vector, normal);
-  gamgi_math_vector_normal (normal);
-  }
+/**************************************************************
+ * get plane normal,rotated according to the cell orientation *
+ **************************************************************/
+
+gamgi_math_quaternion_to_matrix (cell->quaternion, rotate);
+gamgi_phys_plane_vector (cell, plane->hkl, plane->vectors, vector);
+gamgi_math_matrix_vector (rotate, vector, normal);
+gamgi_math_vector_normal (normal);
+
+/**********************************************************
+ * build new planes, link to cell, apply structure policy *
+ **********************************************************/
 
 if (start == end)
   {
-  /************************************************************
-   * build new plane, link plane to cell, link atoms to plane *
-   ************************************************************/
-
   plane->order = start;
   gamgi_phys_plane_cell (plane, cell);
   gamgi_engine_link_plane_cell (plane, cell);
-  if (plane->autonomy == GAMGI_GTK_PARTIAL)
-    static_link (plane, normal, dlist);
-  if (plane->autonomy == GAMGI_GTK_ALL)
+
+  if (plane->structure == GAMGI_CHEM_STRUCTURE_COPY)
     static_copy (plane, normal, dlist);
+  if (plane->structure == GAMGI_CHEM_STRUCTURE_LINK)
+    static_link (plane, normal, dlist);
   }
 else static_multiple (plane, cell, start, end, dlist, normal);
 
