@@ -13,11 +13,11 @@
  * internal functions *
  ********************** 
 
-static void static_create (gamgi_cell *cell, double reciprocal,
-gamgi_enum vectors, int h, int k, int l, double *points, double *origin);
+static void static_create (gamgi_cell *cell,
+gamgi_enum vectors, int h, int k, int l, double *origin);
 
-static void static_create_all (gamgi_cell *cell, double reciprocal,
-int *index, double *transformation, double *orientation);
+static void static_create_all (gamgi_cell *cell, int *index,
+double *transformation, double *orientation);
 
 static void static_conventional_F (gamgi_cell *cell, int *index);
 
@@ -52,11 +52,11 @@ static void static_center (gamgi_plane *plane);
 static gamgi_darray *static_polygon (gamgi_plane *plane,
 double *position, double *normal, gamgi_dlist *dlist);
 
-static void static_link (gamgi_plane *plane,
-double *normal, gamgi_dlist *dlist);
+static void static_copy (gamgi_plane *plane, double *normal,
+gamgi_dlist *start);
 
-static void static_copy (gamgi_plane *plane,
-double *normal, gamgi_dlist *atoms);
+static void static_link (gamgi_plane *plane, double *normal,
+gamgi_dlist *start);
 
 static gamgi_bool static_normal (gamgi_plane *plane, double *normal);
 
@@ -92,7 +92,7 @@ void gamgi_phys_plane_primitive (gamgi_enum lattice,
 int *hkl_c, int *hkl_p);
 
 void gamgi_phys_plane_reciprocal (gamgi_cell *cell, 
-double reciprocal, double *transformation, double *orientation);
+double *transformation, double *orientation);
 
 void gamgi_phys_plane_point (gamgi_plane *plane,
 gamgi_cell *cell, double *point);
@@ -110,9 +110,6 @@ gamgi_atom *atom2, gamgi_atom *atom3, gamgi_window *window);
 gamgi_bool gamgi_phys_plane_reference (gamgi_plane *plane,
 gamgi_atom **atom1, gamgi_atom **atom2, gamgi_atom **atom3);
 
-gamgi_bool gamgi_phys_plane_compatible (gamgi_atom *atom1, 
-gamgi_atom *atom2, gamgi_atom *atom3);
-
 gamgi_bool gamgi_phys_plane_polygon (gamgi_atom *atom1,
 gamgi_atom *atom2, gamgi_atom *atom3);
 
@@ -120,10 +117,10 @@ gamgi_dlist *gamgi_phys_plane_reorder (gamgi_dlist *start,
 gamgi_atom *atom1, gamgi_atom *atom2, gamgi_atom *atom3);
 
 void gamgi_phys_plane_atoms (gamgi_plane *plane, gamgi_atom *atom1,
-gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist, gamgi_bool copy);
+gamgi_atom *atom2, gamgi_atom *atom3, gamgi_dlist *dlist);
 
 void gamgi_phys_plane_polytope (int n_neighbours, gamgi_atom **neighbours,
-gamgi_enum autonomy, float red, float green, float blue, gamgi_object *parent,
+gamgi_enum structure, float red, float green, float blue, gamgi_object *parent,
 gamgi_atom *central);
 
 void gamgi_phys_plane_range (gamgi_plane *plane,
